@@ -30,7 +30,7 @@ using namespace LIFEO;
 // DIALOGSAVEDIARY =================================================================================
 DialogSaveDiary::DialogSaveDiary( void )
 : Gtk::FileChooserDialog(
-        // TRANSLATORS: this is the title of filechooser dialog for saving a new diary
+        // TRANSLATORS: this is the title of file chooser dialog for saving a new diary
         _( "Where to Save The Diary?" ), Gtk::FILE_CHOOSER_ACTION_SAVE )
 {
     add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
@@ -62,17 +62,22 @@ Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_any;
 Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_diary;
 
 DialogOpenDiary::DialogOpenDiary( void )
-:   Gtk::FileChooserDialog(
-        // TRANSLATORS: this is the title of filechooser dialog for selecting a new diary
-        _( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN )
+    // TRANSLATORS: this is the title of file chooser dialog for selecting a new diary
+:   Gtk::FileChooserDialog( _( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN )
 {
-    add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
-    add_button( Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT );
+    add_button( Gtk::Stock::CANCEL, RESPONSE_CANCEL );
+    add_button( _( "Read" ), RESPONSE_READ );
+    add_button( _( "Edit" ), RESPONSE_EDIT );
 
     init_filters();
     add_filter( filter_any );
     add_filter( filter_diary );
     set_filter( filter_diary );
+
+    signal_selection_changed().connect(
+            sigc::mem_fun( this, &DialogOpenDiary::handle_selection_changed ) );
+
+    set_default_response( RESPONSE_EDIT );
 }
 
 void
@@ -92,32 +97,15 @@ DialogOpenDiary::init_filters( void )
     flag_filters_created = true;
 }
 
-// DIALOG PASSWORD PROMPT ==========================================================================
-DialogPasswordPrompt::DialogPasswordPrompt( BaseObjectType* cobject,
-                                            const Glib::RefPtr< Gtk::Builder > &refbuilder )
-:   DialogEvent( cobject, refbuilder )
-{
-    Lifeobase::builder->get_widget_derived( "entry_import_password", m_entry );
-    set_response_sensitive( RESPONSE_GO, false );
-
-    // SIGNALS
-    m_entry->signal_changed().connect(
-            sigc::mem_fun( this,
-                    &DialogPasswordPrompt::handle_entry_changed ) );
-}
-
 void
-DialogPasswordPrompt::on_hide( void )
+DialogOpenDiary::handle_selection_changed( void )
 {
-    m_entry->set_text( "" );
-    m_entry->grab_focus();    // closing with cancel steals focus
-    Gtk::Dialog::on_hide();
-}
+    bool flag_enable( get_filename().size() > 0 );  // check if anything is selected
+    if( flag_enable )
+        flag_enable = ( Glib::file_test( get_filename(), Glib::FILE_TEST_IS_DIR ) == false );
 
-void
-DialogPasswordPrompt::handle_entry_changed( void )
-{
-    set_response_sensitive( RESPONSE_GO, !m_entry->get_text().empty() );
+    set_response_sensitive( RESPONSE_READ, flag_enable );
+    set_response_sensitive( RESPONSE_EDIT, flag_enable );
 }
 
 // DIALOG IMPORT ===================================================================================
@@ -198,6 +186,7 @@ DialogImport::handle_diary_changed( void )
                 Lifeobase::builder->get_widget_derived(
                         "dialog_import_password", m_dialog_password );
             m_dialog_password->set_transient_for( *this );
+            m_dialog_password->set_path( m_diary->get_name() );
             if( m_dialog_password->run() == RESPONSE_GO )
                 m_diary->set_passphrase(
                         m_dialog_password->m_entry->get_text() );
@@ -205,20 +194,18 @@ DialogImport::handle_diary_changed( void )
         }
 
         Result result = m_diary->read_body();
-        if( result == SUCCESS || result == EMPTY_DATABASE )
+        if( result == SUCCESS )
         {
             set_ready();
         }
+        else if( result == WRONG_PASSWORD )
+        {
+            set_not_ready( _( "Entered password is wrong; please try again" ) );
+        }
         else
-            if( result == WRONG_PASSWORD )
-            {
-                set_not_ready(
-                        _( "Entered password is wrong; please try again" ) );
-            }
-            else
-            {
-                set_not_ready( _( "Selected file cannot be read" ) );
-            }
+        {
+            set_not_ready( _( "Selected file cannot be read" ) );
+        }
     }
     else
     {
