@@ -81,7 +81,7 @@ Diary::Diary( void )
     m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
     m_default_theme( ThemeSystem::get() ),
     m_startup_elem( HOME_CURRENT_ELEM ), m_last_elem( DEID_MIN ),
-    m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
+    m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
 #ifdef LIFEOGRAPH_DEBUG_BUILD
     m_flag_ignore_locks( true ),
 #else
@@ -141,52 +141,62 @@ Diary::clear( void )
     m_filtering_status = FS_CLEAR;
 
 	// NOTE: only reset body options here:
-	m_option_spellcheck = true;
+	m_language.clear();
 	m_option_sorting_criteria = SC_DATE;
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
+const Glib::RefPtr< Gdk::Pixbuf >&
 Diary::get_icon( void ) const
 {
 	return Lifeobase::icons->diary_16;
 }
+const Glib::RefPtr< Gdk::Pixbuf >&
+Diary::get_icon32( void ) const
+{
+    return Lifeobase::icons->diary_32;
+}
 
-bool
+LIFEO::Result
 Diary::set_path( const std::string &path, bool new_file, bool read_only )
 {
-    // CHECK PERMISSIONS
-    FILE *fp = fopen( path.c_str(), "r+" );
-    if( fp == NULL )
+    // CHECK FILE SYSTEM PERMISSIONS
+    if( access( path.c_str(), F_OK ) != 0 ) // check existence
     {
-        switch( errno )
+        if( errno == ENOENT )
         {
-            case ENOENT:
-                if( ! new_file )
-                {
-                    print_error( "File not found" );
-                    return false;
-                }
-                break;
-            case EACCES:
-                print_error( "No permission" );
-                read_only = true;
-                break;
+            if( !new_file )
+            {
+                PRINT_DEBUG( "File is not found" );
+                return LIFEO::FILE_NOT_FOUND;
+            }
         }
+        else
+            return LIFEO::FAILURE; // should not be the case
+    }
+    else if( access( path.c_str(), R_OK ) != 0 ) // check read access
+    {
+        PRINT_DEBUG( "File is not readable" );
+        return LIFEO::FILE_NOT_READABLE;
+    }
+    else if( access( path.c_str(), W_OK ) != 0 ) // check write access
+    {
+        // errno == EACCES or errno == EROFS but no need to bother
+        PRINT_DEBUG( "File is not writable, opening read-only..." );
+        read_only = true;
     }
-    else
-        fclose( fp );
 
     // CHECK LOCK
     std::string path_lock( path + LOCK_SUFFIX );
     if( ! new_file && Glib::file_test( path_lock, Glib::FILE_TEST_EXISTS ) )
     {
         if( m_flag_ignore_locks )
-            print_info( "ignored file lock" );
+            print_info( "Ignored file lock" );
         else
         if( ! read_only )
-            return false;
+            return LIFEO::FILE_LOCKED;
     }
 
+    // REMOVE PREVIOUS LOCK IF ANY
     if( ! new_file ) // init_new() clears diary first, so not necessary there
         remove_lock(); // remove existing lock
 
@@ -198,12 +208,12 @@ Diary::set_path( const std::string &path, bool new_file, bool read_only )
 	// "TOUCH" THE NEW LOCK
     if( ! read_only && ! new_file )
     {
-        fp = fopen( path_lock.c_str(), "a+" );
+        FILE *fp = fopen( path_lock.c_str(), "a+" );
         if( fp )
             fclose( fp );
     }
 
-    return true;
+    return LIFEO::SUCCESS;
 }
 
 const std::string&
@@ -524,15 +534,19 @@ Diary::parse_db_body_text( std::stringstream &stream )
 							break;
 					}
 					break;
-				case 'S':	// startup action
-					m_startup_elem = LIFEO::convert_string( line.substr( 2 ) );
-					break;
 				case 'O':	// options
 					if( line.size() < 4 )
 						break;
-					m_option_spellcheck = ( line[ 2 ] == 's' );
+                    if ( line[ 2 ] == 's' ) // for versions prior to 110
+                        m_language = HELPERS::get_env_lang();
 					m_option_sorting_criteria = line[ 3 ];
 					break;
+                case 'l':   // language
+                    m_language = line.substr( 2 );
+                    break;
+                case 'S':	// startup action
+                    m_startup_elem = LIFEO::convert_string( line.substr( 2 ) );
+                    break;
 				case 'L':
 					m_last_elem = LIFEO::convert_string( line.substr( 2 ) );
 					break;
@@ -555,13 +569,18 @@ Diary::parse_db_body_text( std::stringstream &stream )
 				set_force_id( LIFEO::convert_string( line.substr( 2 ) ) );
 				break;
 			case 'E':	// new entry
+            case 'e':   // trashed
 				entry_new = new Entry( this, LIFEO::convert_string( line.substr( 2 ) ),
 									   line[ 1 ] == 'f' );
 				if( m_read_version < 74 )
 					entry_new->m_date.m_date++;	// entry orders should start from 1
-				// TODO: per entry spellcheck options
-				//entry_new->set_spellcheck( opt_spell );
 				m_entries[ entry_new->m_date.m_date ] = entry_new;
+                if( line[ 0 ] == 'e' )
+                {
+                    entry_new->set_trashed( true );
+                    // trashed entries are always hidden at the login
+                    entry_new->set_filtered_out( true );
+                }
 				flag_first_paragraph = true;
 				break;
 			case 'D':	// creation & change dates (optional)
@@ -602,6 +621,12 @@ Diary::parse_db_body_text( std::stringstream &stream )
 						print_error( "Reference to undefined tag: " + line.substr( 2 ) );
 				}
 				break;
+            case 'l':   // language
+                if( entry_new == NULL )
+                    print_error( "No entry declared" );
+                else
+                    entry_new->set_lang( line.substr( 2 ) );
+                break;
 			case 'P':    // paragraph
 				if( entry_new == NULL )
 				{
@@ -639,16 +664,13 @@ Diary::parse_db_body_text( std::stringstream &stream )
 			m_startup_elem = DEID_MIN;
 		}
 
-	if( m_entries.size() )
-	{
-		return LIFEO::SUCCESS;
-	}
-	else
+	if( m_entries.size() < 1 )
 	{
+		print_info( "a dummy entry added to the diary" );
 		add_today();
-		print_info( "empty diary" );
-		return LIFEO::EMPTY_DATABASE;
 	}
+
+	return LIFEO::SUCCESS;
 }
 
 LIFEO::Result
@@ -723,7 +745,8 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 					}
 					break;
 				case 'O':	// options
-					m_option_spellcheck = ( line[2] == 's' );
+                    if ( line[ 2 ] == 's' )
+                        m_language = HELPERS::get_env_lang();
 					break;
 				case 'M':
 					if( m_default_theme == ThemeSystem::get() )
@@ -837,16 +860,13 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
     if( m_chapter_categories.empty() )
         m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
 
-	if( m_entries.size() )
-	{
-		return LIFEO::SUCCESS;
-	}
-	else
-	{
-		add_today();
-		print_info( "empty diary" );
-		return LIFEO::EMPTY_DATABASE;
-	}
+    if( m_entries.size() < 1 )
+    {
+        print_info( "a dummy entry added to the diary" );
+        add_today();
+    }
+
+    return LIFEO::SUCCESS;
 }
 
 LIFEO::Result
@@ -1082,12 +1102,11 @@ Diary::create_db_header_text( std::stringstream &output, bool encrypted )
 bool
 Diary::create_db_body_text( std::stringstream &output )
 {
-	std::string::size_type	pt_start, pt_end;
-	std::string				content_std;
-
 	// OPTIONS
-	output << "O " << ( m_option_spellcheck ? 's' : '-' ) <<
-					  m_option_sorting_criteria << '\n';
+    // dashed char used to be used for spell-checking before v110
+    output << "O -" << m_option_sorting_criteria << '\n';
+    if( !m_language.empty() )
+        output << "l " << m_language << '\n';
 
 	// STARTUP ACTION (HOME ITEM)
 	output << "S " << m_startup_elem << '\n';
@@ -1188,10 +1207,10 @@ Diary::create_db_body_text( std::stringstream &output )
 		else
 		if( entry->get_filtered_out() && m_flag_only_save_filtered ) continue;
 
-
 		// ENTRY DATE
-        output << "ID" << entry->get_id()
-               << "\nE" << ( entry->m_option_favored ? 'f' : ' ' )
+        output << "ID" << entry->get_id() << "\n"
+               << ( entry->is_trashed() ? 'e' : 'E' )
+               << ( entry->m_option_favored ? 'f' : ' ' )
                << entry->m_date.m_date << '\n';
         output << "Dr" << entry->m_date_created << '\n';
         output << "Dh" << entry->m_date_changed << '\n';
@@ -1205,35 +1224,42 @@ Diary::create_db_body_text( std::stringstream &output )
 			 iter_tag != entry->m_tags.end();
 			 ++iter_tag )
 			output << "T " << ( *iter_tag )->get_name_std() << '\n';
+
+        // LANGUAGE
+        if( entry->get_lang() != LANG_INHERIT_DIARY )
+            output << "l " << entry->get_lang() << '\n';
+
 		// CONTENT
-		// NOTE: for some reason, implicit conversion from Glib:ustring...
-		// ...fails while substr()ing when LANG=C
-		// we might reconsider storing text of entries as std::string.
-		// for now we convert entry text to std::string here:
-		content_std = entry->m_text;
-		pt_start = 0;
-
-		while( true )
+		if( entry->m_text.empty() )
+            output << "\n";
+		else
 		{
-			pt_end = content_std.find( '\n', pt_start );
-			if( pt_end == std::string::npos )
-			{
-				pt_end = content_std.size();
-				output	<< "P "
-						<< content_std.substr( pt_start, pt_end - pt_start );
-				break; // end of while( true )
-			}
-			else
-			{
-				pt_end++;
-				output	<< "P "
-						<< content_std.substr( pt_start, pt_end - pt_start );
-				pt_start = pt_end;
-			}
-		}
+            // NOTE: for some reason, implicit conversion from Glib:ustring...
+            // ...fails while substr()ing when LANG=C
+            // we might reconsider storing text of entries as std::string.
+            // for now we convert entry text to std::string here:
+            std::string             content( entry->m_text );
+            std::string::size_type  pt_start( 0 ), pt_end( 0 );
 
-		output << "\n\n";
-	}
+            while( true )
+            {
+                pt_end = content.find( '\n', pt_start );
+                if( pt_end == std::string::npos )
+                {
+                    pt_end = content.size();
+                    output << "P " << content.substr( pt_start, content.size() - pt_start )
+                           << "\n\n";
+                    break; // end of while( true )
+                }
+                else
+                {
+                    pt_end++;
+                    output << "P " << content.substr( pt_start, pt_end - pt_start );
+                    pt_start = pt_end;
+                }
+            }
+        }
+    }
 
 	return true;
 }
@@ -1364,13 +1390,12 @@ bool
 Diary::get_day_has_multiple_entries( const Date &date_impure )
 {
 	Date::date_t date = date_impure.get_pure();
-	Entryiter iter = m_entries.find( date + 1 );
-	if( iter == m_entries.end() || iter == m_entries.begin() )
+	Entryiter iter = m_entries.find( date + 2 );
+	if( iter == m_entries.end() )
 		return false;
 
-	do
+	for( ; iter != m_entries.begin(); --iter )
 	{
-		--iter;
 		if( iter->second->get_date().get_pure() == date )
 		{
 			if( iter->second->get_filtered_out() == false )
@@ -1379,7 +1404,6 @@ Diary::get_day_has_multiple_entries( const Date &date_impure )
 		else
 			break;
 	}
-	while( iter != m_entries.begin() );
 
 	return false;
 }
@@ -1434,8 +1458,6 @@ Diary::create_entry( Date::date_t date, const Glib::ustring &content, bool flag_
 		++date;
 
 	Entry *entry = new Entry( this, date, content, flag_favorite );
-	entry->m_date_created = time( NULL );
-	entry->m_date_changed = entry->m_date_created;
 
 	m_entries[ date ] = entry;
 
@@ -1539,13 +1561,10 @@ Diary::set_filter_text( const Glib::ustring &filter )
 {
 	m_filter_text = filter;
 
-	if( filter.empty() )
-	{
-		if( m_filtering_status & FS_FILTER_TEXT )
-			m_filtering_status -= FS_FILTER_TEXT;
-	}
-	else
-		m_filtering_status |= FS_FILTER_TEXT;
+    if( filter.empty() )
+        m_filtering_status &= ( ~ FS_FILTER_TEXT );
+    else
+        m_filtering_status |= FS_FILTER_TEXT;
 
 	m_filtering_status |= FS_NEW;
 }
@@ -1555,13 +1574,10 @@ Diary::set_filter_tag( const Tag *tag )
 {
 	m_filter_tag = tag;
 
-	if( tag == NULL )
-	{
-		if( m_filtering_status & FS_FILTER_TAG )
-			m_filtering_status -= FS_FILTER_TAG;
-	}
-	else
-		m_filtering_status |= FS_FILTER_TAG;
+    if( tag == NULL )
+        m_filtering_status &= ( ~FS_FILTER_TAG );
+    else
+        m_filtering_status |= FS_FILTER_TAG;
 
 	m_filtering_status |= FS_NEW;
 }
@@ -1577,6 +1593,17 @@ Diary::toggle_filter_favorites( void )
 	m_filtering_status |= FS_NEW;
 }
 
+void
+Diary::toggle_filter_trash( void )
+{
+    if( m_filtering_status & FS_FILTER_TRASH )
+        m_filtering_status -= FS_FILTER_TRASH;
+    else
+        m_filtering_status |= FS_FILTER_TRASH;
+
+    m_filtering_status |= FS_NEW;
+}
+
 void
 Diary::clear_filter_date( void )
 {
@@ -1787,7 +1814,7 @@ Diary::dismiss_chapter( Chapter *chapter )
 		if( flag_last_chapter )
 		{
 			Chapter *chapter_prev( m_topics.get_chapter(
-					Date( d_chapter.m_date - Date::ORDINAL_STEP ) ) );
+					d_chapter.m_date - Date::ORDINAL_STEP ) );
 			Date d_first_free( chapter_prev->get_free_order() );
 			last_order_of_prev_chapter = d_first_free.get_order() - 1;
 		}
@@ -1877,7 +1904,7 @@ Diary::get_free_chapter_order_temporal( void )
 	struct tm *ti = localtime( &t );
 	Date date( ti->tm_year + 1900, ti->tm_mon + 1, ti->tm_mday );
 
-	while( m_ptr2chapter_ctg_cur->get_chapter( date ) )
+	while( m_ptr2chapter_ctg_cur->get_chapter( date.m_date ) )
 	{
 		date.forward_day();
 	}
