@@ -45,10 +45,11 @@ LIFEO::compare_names( const Glib::ustring &name_l, const Glib::ustring &name_r )
 	return( name_l < name_r );
 }
 
-// DIARYELEMENT ================================================================
+// DIARYELEMENT ====================================================================================
 // STATIC MEMBERS
-ListData::Colrec		*ListData::colrec;
-bool					DiaryElement::FLAG_ALLOCATE_GUI_FOR_DIARY = true;
+ListData::Colrec                    *ListData::colrec;
+bool                                DiaryElement::FLAG_ALLOCATE_GUI_FOR_DIARY = true;
+const Glib::RefPtr< Gdk::Pixbuf >   DiaryElement::s_pixbuf_null;
 
 DiaryElement::DiaryElement( DiaryBase * const ptr2diary, const Glib::ustring &name )
 :	NamedElement( name ), m_ptr2diary( ptr2diary ),
@@ -59,7 +60,7 @@ DiaryElement::DiaryElement( DiaryBase * const ptr2diary, const Glib::ustring &na
 }
 
 
-// TAG =========================================================================
+// TAG =============================================================================================
 // STATIC MEMBERS
 ElementShower< Tag >    *Tag::shower( NULL );
 
@@ -74,10 +75,16 @@ Tag::~Tag( void )
 {
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
+const Glib::RefPtr< Gdk::Pixbuf >&
 Tag::get_icon( void ) const
 {
-	return Lifeobase::icons->tag_16;
+    return( this == Diary::d->get_filter_tag() ?
+            Lifeobase::icons->filter_16 : Lifeobase::icons->tag_16 );
+}
+const Glib::RefPtr< Gdk::Pixbuf >&
+Tag::get_icon32( void ) const
+{
+    return( Lifeobase::icons->tag_32 );
 }
 
 void
@@ -160,11 +167,16 @@ CategoryTags::CategoryTags( DiaryBase * const d, const Glib::ustring &name )
 {
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
+const Glib::RefPtr< Gdk::Pixbuf >&
 CategoryTags::get_icon( void ) const
 {
 	return Lifeobase::icons->tag_category_16;
 }
+const Glib::RefPtr< Gdk::Pixbuf >&
+CategoryTags::get_icon32( void ) const
+{
+    return Lifeobase::icons->tag_category_32;
+}
 
 void
 CategoryTags::show( void )
@@ -264,12 +276,18 @@ Chapter::Chapter( DiaryBase * const d, const Glib::ustring &name, Date date )
 {
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
+const Glib::RefPtr< Gdk::Pixbuf >&
 Chapter::get_icon( void ) const
 {
 	return m_date_begin.is_ordinal() ?
 				Lifeobase::icons->chapter_16 : Lifeobase::icons->month_16;
 }
+const Glib::RefPtr< Gdk::Pixbuf >&
+Chapter::get_icon32( void ) const
+{
+    return m_date_begin.is_ordinal() ?
+                Lifeobase::icons->chapter_32 : Lifeobase::icons->month_32;
+}
 
 void
 Chapter::show( void )
@@ -340,18 +358,10 @@ CategoryChapters::~CategoryChapters()
 		delete iter->second;
 }
 
-// not used:
-Glib::RefPtr< Gdk::Pixbuf >&
-CategoryChapters::get_icon( void ) const
-{
-	PRINT_DEBUG( "This function should have never been called: CategoryChapters::get_icon()" );
-	return Lifeobase::icons->chapter_16;
-}
-
 Chapter*
-CategoryChapters::get_chapter( const Date &date )
+CategoryChapters::get_chapter( const Date::date_t date )
 {
-	iterator iter( find( date.m_date ) );
+	iterator iter( find( date ) );
 	return( iter == end() ? NULL : iter->second );
 }
 
@@ -510,7 +520,7 @@ PoolCategoriesChapters::clear( void )
 	std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >::clear();
 }
 
-// THEMES ======================================================================
+// THEMES ==========================================================================================
 // STATIC MEMBERS
 ElementShower< Theme >  *Theme::shower( NULL );
 
@@ -550,10 +560,16 @@ Theme::Theme( const Theme *theme )
 {
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
+const Glib::RefPtr< Gdk::Pixbuf >&
 Theme::get_icon( void ) const
 {
-	return Lifeobase::icons->theme_16;
+	return( this == Diary::d->get_default_theme() ?
+	        Lifeobase::icons->theme_default_16 : Lifeobase::icons->theme_16 );
+}
+const Glib::RefPtr< Gdk::Pixbuf >&
+Theme::get_icon32( void ) const
+{
+    return( Lifeobase::icons->theme_32 );
 }
 
 void
@@ -586,10 +602,10 @@ ThemeSystem::get( void )
 		// this may not be the best method to detect the default font:
 		Gtk::TextView *tv = new Gtk::TextView;
 		tv->show();
-		s_theme = new ThemeSystem( tv->get_style_context()->get_font().to_string(),
-								   "white", "black",
-								   "blue", "violet",
-								   "yellow" );
+        s_theme = new ThemeSystem( tv->get_style_context()->get_font().to_string(),
+                                   "white", "black",
+                                   "blue", "#F066FC",
+                                   "#FFF955" );
 		delete tv;
 		s_flag_initialized = true;
 		return s_theme;
