@@ -41,9 +41,9 @@ const char SYSTEM_THEME[] = "[ - 0 - ]";
 using namespace HELPERS;
 
 typedef char SortingCriteria;
-static const SortingCriteria SC_DATE	= 'd';
-static const SortingCriteria SC_SIZE	= 's';
-//static const SortingCriteria SC_CHANGE_DATE	= 'c';
+static const SortingCriteria SC_DATE    = 'd';
+static const SortingCriteria SC_SIZE    = 's';
+static const SortingCriteria SC_CHANGE  = 'c';  // last change date
 
 typedef unsigned long DEID;	// unique diary element id
 static const DEID	DEID_MIN = 10000;	// reserved for Diary itself
@@ -63,8 +63,8 @@ class DiaryBase
 									PoolDEIDs;
 
                                     DiaryBase( void )
-		:	m_current_id( DEID_MIN ), m_force_id( DEID_UNSET ) {}
-		virtual                     ~DiaryBase() { }
+        :   m_current_id( DEID_MIN ), m_force_id( DEID_UNSET ), m_language( "" ) {}
+		virtual                     ~DiaryBase() {}
 
 		DEID						create_new_id( DiaryElement *element )
 		{
@@ -83,12 +83,7 @@ class DiaryBase
 
 			return retval;
 		}
-
-		void                       erase_id( DEID id )
-		{
-		    m_ids.erase( id );
-		}
-
+        void                        erase_id( DEID id ) { m_ids.erase( id ); }
 		bool						set_force_id( DEID id )
 		{
 			if( m_ids.find( id ) != m_ids.end() || id <= DEID_MIN )
@@ -106,10 +101,14 @@ class DiaryBase
 
 		virtual bool				make_free_entry_order( Date& ) = 0;
 
+        std::string                 get_lang( void ) const { return m_language; }
+        void                        set_lang( const std::string &lang ) { m_language = lang; }
+
 	protected:
 		DEID						m_current_id;
 		DEID						m_force_id;
 		PoolDEIDs					m_ids;
+        std::string                 m_language;
 };
 
 
@@ -140,27 +139,36 @@ class DiaryElement : public NamedElement
 {
 	public:
 		static bool				FLAG_ALLOCATE_GUI_FOR_DIARY;
+        const static Glib::RefPtr< Gdk::Pixbuf >
+                                s_pixbuf_null;
 
 		enum Type
 		{   // CAUTION: order is significant and shouldn't be changed!
 			ET_NONE, ET_TAG, ET_TAG_CTG, ET_THEME, ET_CHAPTER_CTG,
 			// entry list elements:
-			ET_DIARY, ET_CHAPTER, ET_ENTRY, ET_DATE
+			ET_DIARY, ET_CHAPTER, ET_ENTRY, ET_DATE,
+			// special types for pseudo elements:
+			ET_HEADER
 		};
 
 								DiaryElement( DiaryBase * const,
 											  const Glib::ustring& = "" );
 		virtual					~DiaryElement()
 		{
-		    m_ptr2diary->erase_id( m_id );
+		    if( m_ptr2diary != NULL )
+		        m_ptr2diary->erase_id( m_id );
 		}
 
 		virtual Date			get_date( void ) const
 		{ return Date( 0 ); }
 		virtual int				get_size( void ) const = 0;
 		virtual Type			get_type( void ) const = 0;
-		virtual Glib::RefPtr< Gdk::Pixbuf >&
-								get_icon( void ) const = 0;
+        virtual const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon( void ) const
+        { return( s_pixbuf_null ); }
+        virtual const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32( void ) const
+        { return( s_pixbuf_null ); }
 
 		virtual	Glib::ustring	get_list_str( void ) const
 		{ return ""; }
@@ -234,17 +242,17 @@ create_unique_name_for_map( const std::map< Glib::ustring, T*, FuncCompareString
 class ElementShowerProto
 {
     public:
+        ElementShowerProto( void ) : m_menu( NULL ) {}
         virtual             ~ElementShowerProto() {}
 
         virtual DiaryElement*   get_element( void ) = 0;
 
         Gtk::Widget*            get_widget( void )
         { return m_vbox; }
-        Gtk::Widget*            get_toolbar( void )
-        { return m_box_toolbar; }
-
-        virtual Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon_32( void ) const = 0;
+        virtual Menu2*          get_menu( void )
+        { return m_menu; }
+        virtual Gtk::Widget*    get_extra_tools( void )
+        { return NULL; }
 
         virtual Glib::ustring   get_title_str( void ) const
         { return ""; }
@@ -264,15 +272,23 @@ class ElementShowerProto
 
     protected:
         Gtk::Box                *m_vbox;
-        Gtk::Box                *m_box_toolbar;
+        Menu2                   *m_menu;
 };
 
 template< class T >
-struct ElementShower : public ElementShowerProto
+class ElementShower : public ElementShowerProto
 {
+    public:
+        ElementShower() : m_ptr2elem( NULL ) {}
         virtual         ~ElementShower() {}
         virtual void    show( T& ) = 0;
         virtual void    prepare_for_hiding( T& ) {}
+
+        T*              get_element( void )
+        { return m_ptr2elem; }
+
+    protected:
+        T               *m_ptr2elem;
 };
 
 class DiaryElementContainer : public DiaryElement
@@ -316,11 +332,13 @@ class CategoryTags : public DiaryElement, public std::set< Tag*, FuncCompareDiar
 		{ return size(); }
 		Type					get_type( void ) const
 		{ return ET_TAG_CTG; }
-		Glib::RefPtr< Gdk::Pixbuf >&
-								get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32( void ) const;
 
 		Glib::ustring			get_list_str( void ) const
-		{ return Glib::Markup::escape_text( m_name ); }
+		{ return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) ); }
 
 		bool					get_expanded( void ) const
 		{ return m_flag_expanded; }
@@ -332,7 +350,7 @@ class CategoryTags : public DiaryElement, public std::set< Tag*, FuncCompareDiar
 
 	friend class CategoryTagsView;
 	friend class PoolCategoriesTags;
-	friend class TagPanel;
+	friend class PanelExtra;
 };
 
 // POOL OF DEFINED TAG CATEGORIES
@@ -368,8 +386,13 @@ class Tag : public DiaryElementContainer
 		//Date					get_date( void ) const;	// if earliest entry's date is needed
 		Type					get_type( void ) const
 		{ return ET_TAG; }
-		Glib::RefPtr< Gdk::Pixbuf >&
-								get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32( void ) const;
+
+        Glib::ustring           get_list_str( void ) const
+        { return Glib::Markup::escape_text( m_name ); }
 
 	protected:
 		CategoryTags			*m_ptr2category;
@@ -434,8 +457,10 @@ class Chapter : public DiaryElement
 		{ return m_size; }
 		Type					get_type( void ) const
 		{ return ET_CHAPTER; }
-		Glib::RefPtr< Gdk::Pixbuf >&
-								get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32( void ) const;
 
 		Date					get_free_order( void ) const;
 
@@ -480,12 +505,10 @@ class CategoryChapters :
 		{ return size(); }
 		Type					get_type( void ) const
 		{ return ET_CHAPTER_CTG; }
-		Glib::RefPtr< Gdk::Pixbuf >&
-								get_icon( void ) const;
 
 		void					show( void ) {}	// not used
 
-		Chapter*				get_chapter( const Date& );
+		Chapter*				get_chapter( const Date::date_t );
 
 		Chapter*				create_chapter( const Glib::ustring&, const Date& );
 		void					dismiss_chapter( Chapter* );
@@ -537,8 +560,10 @@ class Theme : public DiaryElement
 		{ return 0; }	// redundant
 		DiaryElement::Type			get_type( void ) const
 		{ return ET_THEME; }
-		Glib::RefPtr< Gdk::Pixbuf >&
-									get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32( void ) const;
 
 		Glib::ustring				get_list_str( void ) const
 		{ return Glib::Markup::escape_text( m_name ); }
