@@ -31,44 +31,52 @@ using namespace LIFEO;
 // STATIC MEMBERS
 ElementShower< Entry >  *Entry::shower( NULL );
 
-Entry::Entry( DiaryBase * const d, const Date::date_t date, const Glib::ustring &text, bool flag_favored )
-:	DiaryElement( d ), m_date( date ),
- 	m_date_created( Date::get_ctime( date ) ), m_date_changed( Date::get_ctime( date ) ),
- 	m_text( text ), m_ptr2theme( NULL ), m_option_favored( flag_favored ),
- 	m_flag_filteredout( false )
+Entry::Entry( DiaryBase * const d, const Date::date_t date,const Glib::ustring &text,
+              bool flag_favored )
+:   DiaryElement( d ), m_date( date ),
+    m_date_created( time( NULL ) ), m_date_changed( m_date_created ),
+    m_text( text ), m_ptr2theme( NULL ), m_option_favored( flag_favored ),
+    m_option_lang( LANG_INHERIT_DIARY ),
+    m_option_trashed( false ), m_flag_filteredout( false )
 {
 	calculate_title( text );
 }
 
 Entry::Entry( DiaryBase * const d, const Date::date_t date, bool flag_favored )
-:	DiaryElement( d, _( "<empty entry>" ) ), m_date( date ),
- 	m_date_created( Date::get_ctime( date ) ), m_date_changed( Date::get_ctime( date ) ),
-	m_text( "" ), m_ptr2theme( NULL ), m_option_favored( flag_favored ),
-	m_flag_filteredout( false )
+:   DiaryElement( d, _( STRING::EMPTY_ENTRY_TITLE ) ), m_date( date ),
+    m_date_created( time( NULL ) ), m_date_changed( m_date_created ),
+    m_text( "" ), m_ptr2theme( NULL ), m_option_favored( flag_favored ),
+    m_option_lang( LANG_INHERIT_DIARY ),
+    m_option_trashed( false ), m_flag_filteredout( false )
 {
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
+const Glib::RefPtr< Gdk::Pixbuf >&
 Entry::get_icon( void ) const
 {
 	return( m_option_favored ?
 			Lifeobase::icons->entry_favorite_16 : Lifeobase::icons->entry_16 );
 }
+const Glib::RefPtr< Gdk::Pixbuf >&
+Entry::get_icon32( void ) const
+{
+    return( m_option_favored ?
+            Lifeobase::icons->entry_favorite_32 : Lifeobase::icons->entry_32 );
+}
 
 void
 Entry::calculate_title( const Glib::ustring &text )
 {
-	if( text.size() < 1 )
-	{
-		// TRANSLATORS: title of an empty diary entry
-		m_name = _( "<empty entry>" );
-		return;
-	}
-	unsigned int l_pos = text.find( '\n', 0 );
-	if( l_pos == std::string::npos )
-		m_name = text;
-	else
-		m_name = text.substr( 0, l_pos );
+    if( text.size() < 1 )
+    {
+        m_name = _( STRING::EMPTY_ENTRY_TITLE );
+        return;
+    }
+    unsigned int l_pos = text.find( '\n', 0 );
+    if( l_pos == std::string::npos )
+        m_name = text;
+    else
+        m_name = text.substr( 0, l_pos );
 }
 
 Glib::ustring
@@ -132,10 +140,14 @@ Entry::get_filtered_out( void )
 	 
 	if( filtering_status & Diary::FS_NEW )	// recalculate
 	{
-        m_flag_filteredout = false;
+        //m_flag_filteredout = false;
 
-        if( filtering_status == Diary::FS_NEW )	// FS_NEW alone means not applied clear
-            return false;
+        m_flag_filteredout =
+                ( bool( filtering_status & Diary::FS_FILTER_TRASH ) ^ m_option_trashed );
+
+        // FS_NEW alone means not applied clear
+        if( m_flag_filteredout || filtering_status == Diary::FS_NEW )
+            return m_flag_filteredout;
 
 		// cheapest first: favorites filter
         if( filtering_status & Diary::FS_FILTER_FAVORITES )
