@@ -30,10 +30,13 @@
 namespace LIFEO
 {
 
+const static char LANG_INHERIT_DIARY[] = "d";
+
+
 class Entry : virtual public DiaryElement
 {
 	public:
-		static ElementShower< Entry > *shower;
+        static ElementShower< Entry > *shower;
 
 	typedef sigc::signal< void, Entry* >
 								Signal_void_Entry;
@@ -53,6 +56,8 @@ class Entry : virtual public DiaryElement
 		{ m_text = text; calculate_title( text ); }
 
 		Date					get_date( void ) const { return m_date; }
+        time_t                  get_date_created( void ) const { return m_date_created; }
+        time_t                  get_date_changed( void ) const { return m_date_changed; }
 		Glib::ustring			get_date_created_str( void ) const;
 		Glib::ustring			get_date_changed_str( void ) const;
 		void					set_date( Date date )
@@ -62,10 +67,10 @@ class Entry : virtual public DiaryElement
 		{ return m_text.size(); }
 		Type					get_type( void ) const
 		{ return ET_ENTRY; }
-		Glib::RefPtr< Gdk::Pixbuf >&
-								get_icon( void ) const;
-        Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon_32( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon( void ) const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32( void ) const;
 
 		void					calculate_title( const Glib::ustring& );
 
@@ -80,10 +85,14 @@ class Entry : virtual public DiaryElement
 		bool					is_favored( void ) const { return m_option_favored; }
 		void					set_favored( bool favored ) { m_option_favored = favored; }
 
-		//bool					get_spellcheck( void ) const
-		//{ return m_option_spellcheck; }
-		//void					set_spellcheck( bool opt_spell )
-		//{ m_option_spellcheck = opt_spell; }
+        std::string             get_lang( void ) const { return m_option_lang; }
+        std::string             get_lang_final( void ) const {
+            return m_option_lang == LANG_INHERIT_DIARY ?
+                    m_ptr2diary->get_lang() : m_option_lang; }
+        void                    set_lang( const std::string &lang ) { m_option_lang = lang; }
+
+        bool                    is_trashed( void ) const { return m_option_trashed; }
+        void                    set_trashed( bool trashed ) { m_option_trashed = trashed; }
 
 		void					set_tags( const Tagset& );
 		const Tagset&			get_tags( void ) const;
@@ -113,9 +122,10 @@ class Entry : virtual public DiaryElement
 		Tagset					m_tags;
 		const Theme				*m_ptr2theme;
 
-		bool					m_option_favored;
-		//bool					m_option_spellcheck;	// TODO: per entry spellcheck
-		bool					m_flag_filteredout;
+        bool                    m_option_favored;
+        std::string             m_option_lang;  // empty means off
+        bool                    m_option_trashed;
+        bool                    m_flag_filteredout;
 
 	friend class Diary;	// TODO: remove this friendship too??
 	friend class DiaryView;	// TODO: remove this friendship too??
