@@ -331,7 +331,7 @@ contrast( const Gdk::RGBA &bg, const Gdk::RGBA &fg )
 	int existingcontrast =	abs( fg.get_red_u() - bg.get_red_u() ) +
 							abs( fg.get_green_u() - bg.get_green_u() ) +
 							abs( fg.get_blue_u() - bg.get_blue_u() );
-	if( existingcontrast > 32767 )
+	if( existingcontrast > 60000 )
 		return contrast;
 
 	if( fg.get_red() > fg.get_green() )
@@ -427,6 +427,24 @@ open_url( Gtk::AboutDialog&, const Glib::ustring &link )
 	// TODO: find a better way
 }
 
+// ENVIRONMENT VARIABLES
+std::string
+get_env_lang( void )
+{
+    static std::string s_lang_env( "" );
+    if( s_lang_env.empty() )
+    {
+        const char *lang = g_getenv( "LANG" );
+        if( !lang )
+            s_lang_env = "en";
+        else if( lang[ 0 ] == 0 || strcmp( lang, "C" ) == 0 || strcmp( lang, "c" ) == 0 )
+            s_lang_env = "en";
+        else
+            s_lang_env = lang;
+    }
+    return s_lang_env;
+}
+
 // ENCRYPTION
 bool
 Cipher::init( void )
@@ -606,7 +624,7 @@ Cipher::decrypt_buffer (	unsigned char * buffer,
 	error = gcry_cipher_open( &cipher, cCIPHER_ALGORITHM, cCIPHER_MODE, 0 );
 
 	if( error )
-		throw Error( "Unable to initilize cipher: " ); // + gpg_strerror( Error ) );
+		throw Error( "Unable to initialize cipher: " ); // + gpg_strerror( Error ) );
 
 	// GET KEY LENGTH
 	int cipherKeyLength = gcry_cipher_get_algo_keylen( cCIPHER_ALGORITHM );
@@ -635,7 +653,7 @@ Cipher::decrypt_buffer (	unsigned char * buffer,
 	if( error )
 	{
 		gcry_cipher_close( cipher );
-		throw Error( "Encrption failed: %s" ); // , gpg_strerror( Error ) );
+		throw Error( "Encryption failed: %s" ); // , gpg_strerror( Error ) );
 	}
 
 	gcry_cipher_close( cipher );
@@ -656,33 +674,34 @@ create_menuitem_markup(	const Glib::ustring &str_markup,
 }
 
 // ENTRYIDLETEXT ===================================================================================
-EntryIdletext::EntryIdletext( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
+EntryClear::EntryClear( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
 	:	Gtk::Entry( cobject )
 {
-	signal_icon_release().connect(
-			sigc::mem_fun( *this, &EntryIdletext::handle_clear_icon ) );
+    signal_icon_release().connect( sigc::mem_fun( this, &EntryClear::handle_clear_icon ) );
 }
 
 void
-EntryIdletext::handle_clear_icon( Gtk::EntryIconPosition icon_pos, const GdkEventButton *event )
+EntryClear::handle_clear_icon( Gtk::EntryIconPosition icon_pos, const GdkEventButton *event )
 {
 	if( icon_pos == Gtk::ENTRY_ICON_SECONDARY && event->button == 1 )
 		set_text( "" );
 }
 
 void
-EntryIdletext::on_changed( void )
+EntryClear::on_changed( void )
 {
     if( get_text().empty() )
     {
         // Fall-back to C API as gtkmm has problems with this:
-        // TODO: is this still the case with gtkmm-3?
-        gtk_entry_set_icon_from_stock( gobj(), GTK_ENTRY_ICON_SECONDARY, 0 );
+        unset_icon( Gtk::ENTRY_ICON_SECONDARY );
         set_icon_activatable( false, Gtk::ENTRY_ICON_SECONDARY );
     }
     else
     {
-        set_icon_from_stock( Gtk::Stock::CLEAR, Gtk::ENTRY_ICON_SECONDARY );
+        //set_icon_from_stock( Gtk::Stock::CLEAR, Gtk::ENTRY_ICON_SECONDARY );
+        set_icon_from_pixbuf(
+                Gtk::IconTheme::get_default()->load_icon( "edit-clear-symbolic", 16 ),
+                Gtk::ENTRY_ICON_SECONDARY );
         set_icon_activatable( true, Gtk::ENTRY_ICON_SECONDARY );
     }
 
@@ -690,7 +709,7 @@ EntryIdletext::on_changed( void )
 }
 
 bool
-EntryIdletext::on_key_release_event( GdkEventKey *event )
+EntryClear::on_key_release_event( GdkEventKey *event )
 {
 	if( event->keyval == GDK_KEY_Escape )
 		set_text( "" );
@@ -713,17 +732,18 @@ Menubutton::Menubutton(	const Gtk::StockID &stockid,
 	if( menu == NULL )
 		m_menu = new Menu2;
 	Gtk::Box *hbox = Gtk::manage( new Gtk::Box );
-	m_icon = Gtk::manage( new Gtk::Image( stockid, iconsize ) );
+	Gtk::Image *icon = Gtk::manage( new Gtk::Image( stockid, iconsize ) );
 	m_label = Gtk::manage( new Gtk::Label( label ) );
 	Gtk::Arrow *arrow = Gtk::manage(
 			new Gtk::Arrow(Gtk::ARROW_DOWN, Gtk::SHADOW_IN) );
 
-	hbox->pack_start( *m_icon, Gtk::PACK_SHRINK );
+	hbox->pack_start( *icon, Gtk::PACK_SHRINK );
 	hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
 	hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
 	add( *hbox );
 	m_menu->attach_to_widget( *this );
-	m_menu->signal_deactivate().connect( sigc::mem_fun( *this, &Menubutton::release ) );
+    m_connection = m_menu->signal_deactivate().connect(
+            sigc::mem_fun( *this, &Menubutton::release ) );
 	add_events( Gdk::BUTTON_PRESS_MASK );
 }
 
@@ -735,15 +755,16 @@ Menubutton::Menubutton(	const Glib::RefPtr< Gdk::Pixbuf > *pixbuf,
 :   Gtk::ToggleButton(), m_menu( menu )
 {
 	set_relief( style );
-	Gtk::Arrow *arrow;
-	Gtk::Box *hbox;
+	Gtk::Arrow *arrow( NULL );
+	Gtk::Image *icon( NULL );
+	Gtk::Box *hbox( NULL );
 	try
 	{
 		if( menu == NULL )
 			m_menu = new Menu2;
 		hbox = Gtk::manage( new Gtk::Box );
 		if( pixbuf )
-			m_icon = Gtk::manage( new Gtk::Image( *pixbuf ) );
+			icon = Gtk::manage( new Gtk::Image( *pixbuf ) );
 		m_label = Gtk::manage( new Gtk::Label( label ) );
 		arrow = Gtk::manage( new Gtk::Arrow( Gtk::ARROW_DOWN, Gtk::SHADOW_IN ) );
 	}
@@ -753,32 +774,38 @@ Menubutton::Menubutton(	const Glib::RefPtr< Gdk::Pixbuf > *pixbuf,
 	}
 
 	if( pixbuf )
-		hbox->pack_start( *m_icon, Gtk::PACK_SHRINK );
+		hbox->pack_start( *icon, Gtk::PACK_SHRINK );
 	hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
 	hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
 	add( *hbox );
 	m_menu->attach_to_widget( *this );
-	m_menu->signal_deactivate().connect( sigc::mem_fun( *this, &Menubutton::release ) );
+    m_connection = m_menu->signal_deactivate().connect(
+            sigc::mem_fun( *this, &Menubutton::release ) );
 	add_events( Gdk::BUTTON_PRESS_MASK );
 }
 
 Menubutton::Menubutton( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder> &builder )
-:   Gtk::ToggleButton( cobject )
+:   Gtk::ToggleButton( cobject ), m_menu( NULL )
 {
-    try
+    if( !s_builder_name.empty() )
     {
-        builder->get_widget_derived( s_builder_name + "_menu", m_menu );
-        builder->get_widget( s_builder_name + "_icon", m_icon );
-        builder->get_widget( s_builder_name + "_label", m_label );
-        s_builder_name = "";
-    }
-    catch( ... )
-    {
-        throw Error( "Menubutton creation failed" );
+        try
+        {
+            builder->get_widget_derived( s_builder_name + "_menu", m_menu );
+            //builder->get_widget( s_builder_name + "_icon", m_icon );
+            //builder->get_widget( s_builder_name + "_label", m_label );
+            s_builder_name = "";
+        }
+        catch( ... )
+        {
+            throw Error( "Menubutton creation failed" );
+        }
+
+        m_menu->attach_to_widget( *this );
+        m_connection = m_menu->signal_deactivate().connect(
+                sigc::mem_fun( this, &Menubutton::release ) );
     }
 
-    m_menu->attach_to_widget( *this );
-    m_menu->signal_deactivate().connect( sigc::mem_fun( this, &Menubutton::release ) );
     add_events( Gdk::BUTTON_PRESS_MASK );
 }
 
@@ -793,11 +820,36 @@ Menubutton::get_menu( void ) const
 	return m_menu;
 }
 
+void
+Menubutton::set_menu( Menu2 *menu )
+{
+    if( m_menu == menu )
+        return;
+
+    if( m_menu )
+    {
+        m_menu->detach();
+        m_connection.disconnect();
+    }
+
+    m_menu = menu;
+
+    set_sensitive( menu != NULL );
+
+    if( menu )
+    {
+        m_menu->attach_to_widget( *this );
+        m_connection = m_menu->signal_deactivate().connect(
+                sigc::mem_fun( this, &Menubutton::release ) );
+    }
+}
+
 bool
 Menubutton::clear_menu( void )
 {
-	if ( m_menu->get_children().size() > 0 )
+	if( m_menu->get_children().size() > 0 )
 	{
+        m_menu->detach();
 		delete m_menu;
 		m_menu = new Menu2;
 		m_menu->attach_to_widget( *this );
@@ -1172,7 +1224,6 @@ void
 FilebuttonRecent::show_filechooser( void )
 {
 	m_filechooserdialog = new Gtk::FileChooserDialog(
-	// TRANSLATORS: this is the title of filechooser dialog for selecting a new diary
 			_( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN );
 
 	if( m_list_recent->size() > 0 )
