@@ -310,8 +310,10 @@ convert_gdkrgba_to_string( const Gdk::RGBA &gdkcolor )
 }
 std::ios::pos_type	get_file_size( std::ifstream& );
 
-void				open_url( Gtk::AboutDialog&, const Glib::ustring& );
-void				mail_to( Gtk::AboutDialog&, const Glib::ustring& );
+void                open_url( Gtk::AboutDialog&, const Glib::ustring& );
+void                mail_to( Gtk::AboutDialog&, const Glib::ustring& );
+
+std::string         get_env_lang( void );
 
 Gtk::MenuItem*		create_menuitem_markup( const Glib::ustring&,
 											const Glib::SignalProxy0< void >::SlotType& );
@@ -376,12 +378,11 @@ class Cipher
 
 };
 
-// ENTRY WIDGET WITH TIP TEXT WHEN IDLE ============================================================
-class EntryIdletext : public Gtk::Entry
+// ENTRY WIDGET WITH SELF-HANDLED CLEAR ICON =======================================================
+class EntryClear : public Gtk::Entry
 {
 	public:
-							EntryIdletext( BaseObjectType*, const Glib::RefPtr<Gtk::Builder>& );
-		explicit			EntryIdletext( const Glib::ustring& );
+                            EntryClear( BaseObjectType*, const Glib::RefPtr<Gtk::Builder>& );
 
 	protected:
 		void				handle_clear_icon( Gtk::EntryIconPosition, const GdkEventButton* );
@@ -421,6 +422,7 @@ class Menubutton : public Gtk::ToggleButton
 		virtual				~Menubutton( void );
 
         Menu2*              get_menu( void ) const;
+        void                set_menu( Menu2* );
 		bool				clear_menu( void );
 		void				release( void );
 
@@ -435,11 +437,9 @@ class Menubutton : public Gtk::ToggleButton
 
 		Menu2				*m_menu;
 		Gtk::Label			*m_label;
-		Gtk::Image			*m_icon;
+        sigc::connection    m_connection;
 
 	private:
-
-	friend class Menutoolbutton;
 };
 
 /*
