@@ -34,7 +34,6 @@
 #include "panel_main.hpp"
 #include "panel_diary.hpp"
 #include "widget_textview.hpp"
-#include "widget_panel_exp.hpp"
 #include "dialog_export.hpp"
 #include "view_entry.hpp"
 #include "view_login.hpp"
@@ -71,19 +70,18 @@ class Lifeograph : public Lifeobase
 							Lifeograph( int, char** );
 							~Lifeograph ();
 
-		void                on_run( void );
-
 		void				draw_welcomescreen( void );
 		void				draw_loginscreen( void );
-		void				draw_editscreen( void );
 
-		void				update_theme_list( void );
 		void				update_title( void );
 
-		bool				confirm_dismiss_element( void );
-		Gtk::TreeRow		get_element_row( DiaryElement* );
+        void                freeze_auto_logout( void );
+        void                unfreeze_auto_logout( void );
 
-		bool				write_backup( void );
+		bool				confirm_dismiss_element( void );
+		Gtk::TreeRow		get_element_row( const DiaryElement* );
+
+		void				login( void );
 		bool				finish_editing( bool = true );
 		void				logout( bool );
 
@@ -91,6 +89,8 @@ class Lifeograph : public Lifeobase
 		bool				handle_idle( void );
 		void				show_about( void );
 
+		bool				write_backup( void );
+
 		void				handle_textview_entry_changed( void );
 
 		void				handle_undo( void );
@@ -106,11 +106,8 @@ class Lifeograph : public Lifeobase
 		Gtk::HPaned					*m_hpaned_entry;
 		Gtk::HPaned					*m_hpaned_main;
 
-        Gtk::Button                 *m_button_logout;
-
 		sigc::connection			m_connection_backup;
 
-		WidgetPanelExp				*m_widget_panel_exp;
         ViewLogin                   *m_view_login;
 		DiaryView					*m_diary_view;
 		CategoryTagsView			*m_category_tags_view;
@@ -125,6 +122,7 @@ class Lifeograph : public Lifeobase
 		const std::string			m_programpath;
 		bool						m_flag_firsttimeuser;
         bool                        m_flag_force_welcome;
+        bool                        m_flag_auto_logout_frozen;
 };
 
 } // end of namespace LIFEO
