@@ -52,6 +52,16 @@ PanelDiary::PanelDiary( void )
         Lifeobase::builder->get_widget( "menuitem_sort_by_size", m_menuitem_sort_by_size );
         Lifeobase::builder->get_widget( "menuitem_sort_by_change", m_menuitem_sort_by_change );
 
+        // FALLBACK ICON FOR SYSTEMS WITHOUT SYMBOLIC ICONS
+        Glib::RefPtr< Gtk::IconTheme > theme = Gtk::IconTheme::get_default();
+        if( ! theme->has_icon( "preferences-system-symbolic" ) &&
+            theme->has_icon( "gtk-preferences" ) )
+        {
+            Glib::RefPtr< Gdk::Pixbuf > icon_tools = theme->load_icon( "gtk-preferences", 16 );
+            Gtk::Image *img_tools = Gtk::manage( new Gtk::Image( icon_tools ) );
+            mb_tools->set_image( *img_tools );
+        }
+
         Lifeobase::builder->get_widget( "togglebtn_filter_favorites",
                                         m_togglebtn_filter_favorites );
         Lifeobase::builder->get_widget( "togglebtn_filter_trash", m_togglebtn_filter_trash );
