@@ -52,8 +52,10 @@ class PanelDiary
 		void					handle_calendar_dayselected( void );
 		void					select_date_in_calendar( const Date& );
 
-		void					handle_filter_favorites_toggled( void );
-		void					remove_filters( void );
+        void                    handle_filter_favorites_toggled( void );
+        void                    handle_filter_trash_toggled( void );
+        void                    remove_filters( void );
+
 		void					handle_login( void );
 		void					handle_logout( void );
 
@@ -79,9 +81,10 @@ class PanelDiary
 
 		WidgetEntryList			*m_treeview_entries;
 
+        Gtk::Button             *m_button_logout;
 		Gtk::Calendar			*m_calendar;
-		EntryIdletext			*m_entry_filter;
-		EntryIdletext			*m_entry_replace;
+        EntryClear              *m_entry_filter;
+        EntryClear              *m_entry_replace;
         Gtk::Button             *m_button_match_prev;
         Gtk::Button             *m_button_match_next;
         Gtk::Box                *m_toolbar_replace;
@@ -90,8 +93,10 @@ class PanelDiary
 
 		Gtk::RadioMenuItem		*m_menuitem_sort_by_date;
 		Gtk::RadioMenuItem		*m_menuitem_sort_by_size;
+        Gtk::RadioMenuItem      *m_menuitem_sort_by_change;
 
 		Gtk::ToggleButton       *m_togglebtn_filter_favorites;
+        Gtk::ToggleButton       *m_togglebtn_filter_trash;
 		Gtk::Button             *m_button_remove_filters;
 
 		Menubutton              *m_button_add;
