@@ -29,56 +29,58 @@ using namespace LIFEO;
 PanelMain *Lifeobase::panel_main = NULL;
 
 PanelMain::PanelMain( void )
-:	m_bhist_index( 0 ), m_ptr2widget( NULL ), m_entry_gelem_title( NULL ),
-    m_current_gelem_toolbar( NULL ), m_flag_index_locked( false )
+:   m_bhist_index( 0 ), m_flag_index_locked( false ), m_flag_title_edit_in_progress( false ),
+    m_ptr2widget( NULL ), m_entry_elem_title( NULL )
 {
 	Lifeobase::builder->get_widget( "vbox_panel_main", m_vbox_content );
-    Lifeobase::builder->get_widget( "label_gui_elem", m_label_gui_elem );
-    Lifeobase::builder->get_widget( "label_gelem_extra", m_label_gelem_extra );
-    Lifeobase::builder->get_widget( "eventbox_gelem_title", m_eventbox_gelem_title );
-    Lifeobase::builder->get_widget( "button_gui_elem", m_button_gui_elem );
-    Lifeobase::builder->get_widget( "image_gui_elem", m_image_gui_elem );
-    Lifeobase::builder->get_widget( "align_gelem_toolbar", m_align_gelem_toolbar );
-    Lifeobase::builder->get_widget( "align_gelem_title", m_align_gelem_title );
+    Lifeobase::builder->get_widget( "align_header_title", m_align_elem_title );
+    Lifeobase::builder->get_widget( "eventbox_header_title", m_eventbox_elem_title );
+    Lifeobase::builder->get_widget( "label_header_title", m_label_elem_title );
+    Lifeobase::builder->get_widget( "label_header_subtitle", m_label_elem_extra );
+    Lifeobase::builder->get_widget( "button_header_back", m_button_back );
+    Lifeobase::builder->get_widget( "image_header_elem", m_image_elem );
+    Menubutton::s_builder_name = "";
+    Lifeobase::builder->get_widget_derived( "menubutton_header_elem", m_button_menu );
+    Lifeobase::builder->get_widget( "alignment_header_extra_tools", m_alignment_extra_tools );
 
-    m_entry_gelem_title = new Gtk::Entry;
+    m_entry_elem_title = new Gtk::Entry;
 
 	for( int i = 0; i < BROWSING_HISTORY_SIZE; i++ )
 		m_browsing_history[ i ] = NULL;
 
-	m_eventbox_gelem_title->signal_button_press_event().connect(
+    m_entry_elem_title->set_icon_activatable( true, Gtk::ENTRY_ICON_SECONDARY );
+
+	m_eventbox_elem_title->signal_button_press_event().connect(
 	        sigc::mem_fun( this, &PanelMain::handle_title_click ) );
-    m_eventbox_gelem_title->signal_enter_notify_event().connect(
+    m_eventbox_elem_title->signal_enter_notify_event().connect(
             sigc::mem_fun( this, &PanelMain::handle_title_hover ) );
-    m_eventbox_gelem_title->signal_leave_notify_event().connect(
+    m_eventbox_elem_title->signal_leave_notify_event().connect(
             sigc::mem_fun( this, &PanelMain::handle_title_hover_out ) );
-    m_entry_gelem_title->signal_changed().connect(
+    m_entry_elem_title->signal_changed().connect(
             sigc::mem_fun( this, &PanelMain::handle_entry_title_changed ) );
-    m_entry_gelem_title->signal_key_press_event().connect(
+    m_entry_elem_title->signal_key_press_event().connect(
             sigc::mem_fun( this, &PanelMain::handle_entry_title_key_press ) );
-    m_entry_gelem_title->signal_focus_out_event().connect(
+    m_entry_elem_title->signal_focus_out_event().connect(
             sigc::mem_fun( this, &PanelMain::handle_entry_title_focus_out ) );
-    m_entry_gelem_title->signal_icon_release().connect(
+    m_entry_elem_title->signal_icon_release().connect(
             sigc::mem_fun( this, &PanelMain::handle_entry_icon_release ) );
-    m_entry_gelem_title->signal_activate().connect(
+    m_entry_elem_title->signal_activate().connect(
             sigc::mem_fun( this, &PanelMain::apply_title_edit ) );
 
     Lifeobase::create_action(
-            m_action_previous_browsing,
-            "BrowseBack",
-            Gtk::Stock::GO_BACK,
+            false, m_action_previous_browsing, "BrowseBack", Gtk::Stock::GO_BACK,
             "", "",
             Gtk::AccelKey( GDK_KEY_Left, Gdk::MOD1_MASK ),
             sigc::mem_fun( this, &PanelMain::go_back ) );
 
-    m_button_gui_elem->set_related_action( m_action_previous_browsing );
+    m_button_back->set_related_action( m_action_previous_browsing );
 }
 
 void
 PanelMain::show( ElementShowerProto *shower )
 {
     if( m_flag_title_edit_in_progress )
-        m_button_gui_elem->grab_focus();    // cancel editing
+        m_button_back->grab_focus();    // cancel editing
 
 	// prepare last element for hiding:
 	if( m_browsing_history[ m_bhist_index ] )
@@ -97,18 +99,16 @@ PanelMain::show( ElementShowerProto *shower )
 	Lifeobase::m_internaloperation++;
 
 	// HEADER TEXTS
-    m_label_gui_elem->set_text( shower->get_title_str() );
-    m_label_gui_elem->set_tooltip_markup( shower->get_tip_str() );
-    m_label_gelem_extra->set_text( shower->get_info_str() );
+    m_label_elem_title->set_text( shower->get_title_str() );
+    m_label_elem_title->set_tooltip_markup( shower->get_tip_str() );
+    m_label_elem_extra->set_text( shower->get_info_str() );
 
     // ICON
-    m_image_gui_elem->set( shower->get_icon_32() );
+    m_image_elem->set( shower->get_element()->get_icon32() );
 
     // TOOLBAR
-    if( Diary::d->is_read_only() )
-        set_gelem_toolbar( NULL );
-    else
-        set_gelem_toolbar( shower->get_toolbar() );
+    m_button_menu->set_menu( shower->get_menu() );
+    set_extra_tools( shower->get_extra_tools() );
 
     // CONTENT
 	if( m_ptr2widget != shower->get_widget() )
@@ -129,15 +129,27 @@ PanelMain::show( ElementShowerProto *shower )
 }
 
 void
-PanelMain::set_gelem_toolbar( Gtk::Widget *toolbar )
+PanelMain::handle_logout( void )
 {
-    if( m_current_gelem_toolbar != NULL )
-        m_align_gelem_toolbar->remove();
+    if( m_flag_title_edit_in_progress )
+    {
+        m_flag_title_edit_in_progress = false;  // must be first
 
-    m_current_gelem_toolbar = toolbar;
+        m_align_elem_title->remove();
+        m_align_elem_title->add( *m_eventbox_elem_title );
+    }
 
-    if( toolbar != NULL )
-        m_align_gelem_toolbar->add( *toolbar );
+    clear_history();
+}
+
+void
+PanelMain::set_extra_tools( Gtk::Widget *tool )
+{
+    if( m_alignment_extra_tools->get_child() )
+        m_alignment_extra_tools->remove();
+
+    if( tool != NULL )
+        m_alignment_extra_tools->add( *tool );
 }
 
 void
@@ -181,34 +193,44 @@ PanelMain::start_title_edit( void )
 {
     if( m_flag_title_editable )
     {
-        m_align_gelem_title->remove();
+        m_align_elem_title->remove();
 
-        m_align_gelem_title->add( *m_entry_gelem_title );
-        m_entry_gelem_title->show();
-        m_entry_gelem_title->set_text( m_cur_shower->get_title_edit_str() );
-        m_entry_gelem_title->grab_focus();
-        m_entry_gelem_title->set_icon_from_stock( Gtk::Stock::DIALOG_WARNING,
+        m_align_elem_title->add( *m_entry_elem_title );
+        m_entry_elem_title->show();
+        m_entry_elem_title->set_text( m_cur_shower->get_title_edit_str() );
+        m_entry_elem_title->grab_focus();
+        m_entry_elem_title->set_icon_from_stock( Gtk::Stock::DIALOG_WARNING,
                 Gtk::ENTRY_ICON_SECONDARY );
-        m_entry_gelem_title->set_icon_activatable( false, Gtk::ENTRY_ICON_SECONDARY );
 
         m_flag_title_applicable = false;
         m_flag_title_edit_in_progress = true;
     }
 }
 
+void
+PanelMain::cancel_title_edit( void )
+{
+    if( m_flag_title_edit_in_progress )
+    {
+        m_flag_title_edit_in_progress = false;  // must be first
+
+        m_align_elem_title->remove();
+        m_align_elem_title->add( *m_eventbox_elem_title );
+        m_label_elem_title->set_text( m_cur_shower->get_title_str() );
+    }
+}
+
 void
 PanelMain::handle_entry_title_changed( void )
 {
     if( m_flag_title_edit_in_progress )
     {
         m_flag_title_applicable = m_cur_shower->check_title_applicable(
-                m_entry_gelem_title->get_text() );
+                m_entry_elem_title->get_text() );
 
-        m_entry_gelem_title->set_icon_from_stock( m_flag_title_applicable ?
+        m_entry_elem_title->set_icon_from_stock( m_flag_title_applicable ?
                 Gtk::Stock::APPLY : Gtk::Stock::DIALOG_WARNING,
                 Gtk::ENTRY_ICON_SECONDARY );
-        m_entry_gelem_title->set_icon_activatable( m_flag_title_applicable,
-                                                   Gtk::ENTRY_ICON_SECONDARY );
     }
 }
 
@@ -217,13 +239,13 @@ PanelMain::apply_title_edit( void )
 {
     if( m_flag_title_applicable )
     {
-        Glib::ustring str( m_entry_gelem_title->get_text() );
+        Glib::ustring str( m_entry_elem_title->get_text() );
 
-        m_button_gui_elem->grab_focus();    // cancel editing
+        m_button_back->grab_focus();    // cancel editing
 
         m_cur_shower->apply_title( str );
 
-        m_label_gui_elem->set_text( m_cur_shower->get_title_str() );
+        m_label_elem_title->set_text( m_cur_shower->get_title_str() );
     }
 }
 
@@ -239,14 +261,7 @@ PanelMain::handle_title_click( GdkEventButton* )
 bool
 PanelMain::handle_entry_title_focus_out( GdkEventFocus* )
 {
-    if( m_flag_title_edit_in_progress )
-    {
-        m_align_gelem_title->remove();
-        m_align_gelem_title->add( *m_eventbox_gelem_title );
-        m_label_gui_elem->set_text( m_cur_shower->get_title_str() );
-
-        m_flag_title_edit_in_progress = false;
-    }
+    cancel_title_edit();
 
     return false;
 }
@@ -255,7 +270,7 @@ bool
 PanelMain::handle_entry_title_key_press( GdkEventKey *event )
 {
     if( event->keyval == GDK_KEY_Escape )
-        m_button_gui_elem->grab_focus();    // cancel editing
+        m_button_back->grab_focus();    // cancel editing
     return true;
 }
 
@@ -263,7 +278,7 @@ bool
 PanelMain::handle_title_hover( GdkEventCrossing* )
 {
     if( m_flag_title_editable )
-        m_label_gui_elem->set_markup(
+        m_label_elem_title->set_markup(
                 "<u>" + Glib::Markup::escape_text( m_cur_shower->get_title_str() ) + "</u>" );
     return false;
 }
@@ -272,7 +287,7 @@ bool
 PanelMain::handle_title_hover_out( GdkEventCrossing* )
 {
     if( m_flag_title_editable )
-        m_label_gui_elem->set_text( m_cur_shower->get_title_str() );
+        m_label_elem_title->set_text( m_cur_shower->get_title_str() );
     return false;
 }
 
@@ -280,5 +295,8 @@ void
 PanelMain::handle_entry_icon_release( Gtk::EntryIconPosition icon_position,
                                       const GdkEventButton* event )
 {
-    apply_title_edit();
+    if( m_flag_title_applicable )
+        apply_title_edit();
+    else
+        cancel_title_edit();
 }
