@@ -47,6 +47,8 @@ class PanelMain
         { return( elem == get_cur_elem() ); }
 
 		void					show( ElementShowerProto* );
+
+        void                    handle_logout( void );
 	
 		void					go_back( void );
 		//void					go_forward( void );
@@ -64,16 +66,20 @@ class PanelMain
 
         void                    set_icon( const Glib::RefPtr< Gdk::Pixbuf > icon )
         {
-            m_image_gui_elem->set( icon );
+            m_image_elem->set( icon );
         }
-        void                    set_gelem_toolbar( Gtk::Widget* );
 
         void                    start_title_edit( void );
+        void                    cancel_title_edit( void );
         void                    apply_title_edit( void );
         // for entries whose title is partly defined by contents of entry text editor:
-        void                    handle_title_changed_outside( void )
+        void                    refresh_title( void )
         {
-            m_label_gui_elem->set_text( m_cur_shower->get_title_str() );
+            m_label_elem_title->set_text( m_cur_shower->get_title_str() );
+        }
+        void                    refresh_extra_info( void )
+        {
+            m_label_elem_extra->set_text( m_cur_shower->get_info_str() );
         }
 
         bool                    handle_entry_title_focus_out( GdkEventFocus* );
@@ -88,27 +94,30 @@ class PanelMain
 		PtrDiaryElement			m_browsing_history[ BROWSING_HISTORY_SIZE ];
 		unsigned int			m_bhist_index;	// browsing history index
 
-		ElementShowerProto      *m_cur_shower;
-
-		Gtk::Widget				*m_ptr2widget;
-        Gtk::Box                *m_vbox_content;
-
-        Gtk::Label              *m_label_gui_elem;
-        Gtk::Label              *m_label_gelem_extra;
-        Gtk::EventBox           *m_eventbox_gelem_title;
-        Gtk::Entry              *m_entry_gelem_title;
-        Gtk::Button             *m_button_gui_elem;
-        Gtk::Image              *m_image_gui_elem;
-        Gtk::Alignment          *m_align_gelem_toolbar;
-        Gtk::Alignment          *m_align_gelem_title;
-        Gtk::Widget             *m_current_gelem_toolbar;
-
-        Glib::RefPtr< Gtk::Action > m_action_previous_browsing;
+    protected:
+        void                    set_extra_tools( Gtk::Widget* );
 
         bool                    m_flag_index_locked;
         bool                    m_flag_title_edit_in_progress;
         bool                    m_flag_title_editable;
         bool                    m_flag_title_applicable;
+
+        ElementShowerProto      *m_cur_shower;
+
+        Gtk::Widget             *m_ptr2widget;
+        Gtk::Box                *m_vbox_content;
+
+        Gtk::Alignment          *m_align_elem_title;
+        Gtk::EventBox           *m_eventbox_elem_title;
+        Gtk::Label              *m_label_elem_title;
+        Gtk::Entry              *m_entry_elem_title;
+        Gtk::Label              *m_label_elem_extra;
+        Gtk::Button             *m_button_back;
+        Gtk::Image              *m_image_elem;
+        Menubutton              *m_button_menu;
+        Gtk::Alignment          *m_alignment_extra_tools;
+
+        Glib::RefPtr< Gtk::Action > m_action_previous_browsing;
 };
 
 
