@@ -34,8 +34,11 @@ Undoable::Undoable( const Glib::ustring& name, UndoableType type )
 }
 
 // UNDO MANAGER
+// static undo manager
+UndoManager *UndoManager::m = NULL;
+
 UndoManager::UndoManager( void )
-: m_freezed( false )
+	:	m_freezed( false )
 {
 
 }
