@@ -29,6 +29,7 @@
 #include "diary.hpp"
 #include "views.hpp"
 #include "widget_textview.hpp"
+#include "widget_tag_list.hpp"
 
 
 namespace LIFEO
@@ -42,66 +43,67 @@ class EntryView : public ElementShower< Entry >
 		void					sync( void );
 
 		void					focus_tag( void );
-		//bool					handle_hboxtagtools_enternotify( GdkEventCrossing * );
 
         Glib::ustring           get_title_str( void ) const
         {
-            if( m_ptr2entry->get_date().is_ordinal() )
+            if( m_ptr2elem->get_date().is_ordinal() )
                 return Glib::ustring::compose( "%1: %2",
-                                               m_ptr2entry->get_date().format_string(),
-                                               m_ptr2entry->m_name );
+                                               m_ptr2elem->get_date().format_string(),
+                                               m_ptr2elem->m_name );
             else
                 return Glib::ustring::compose( "%1, %2",
-                                               m_ptr2entry->get_date().format_string(),
-                                               m_ptr2entry->get_date().get_weekday_str() );
+                                               m_ptr2elem->get_date().format_string(),
+                                               m_ptr2elem->get_date().get_weekday_str() );
         }
         Glib::ustring           get_info_str( void ) const
         { return Glib::ustring::compose( "Entry last changed on %1",
-                Date::format_string_do( m_ptr2entry->m_date_changed ) ); }
+                Date::format_string_do( m_ptr2elem->m_date_changed ) ); }
         Glib::ustring           get_tip_str( void ) const
         {
-            return Glib::ustring::compose( "%1: <b>%2</b>\n%3: <b>%4</b>\nDEID:%5",
+            return Glib::ustring::compose( "%1: <b>%2</b>\n%3: <b>%4</b>"
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+                    "\nDEID: %5"
+#endif
                     // TRANSLATORS: label of creation date
-                    _( "Created"), m_ptr2entry->get_date_created_str(),
+                    , _( "Created"), m_ptr2elem->get_date_created_str(),
                     // TRANSLATORS: label of last change date
-                    _( "Changed"), m_ptr2entry->get_date_changed_str(),
-                    m_ptr2entry->get_id() );
+                    _( "Changed"), m_ptr2elem->get_date_changed_str()
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+                    , m_ptr2elem->get_id()
+#endif
+                    );
         }
 
         bool                    is_title_editable( void ) const
-        { return( ! m_ptr2entry->get_date().is_ordinal() ); }
+        { return( ! m_ptr2elem->get_date().is_ordinal() ); }
         Glib::ustring           get_title_edit_str( void ) const
-        { return( m_ptr2entry->get_date().format_string() ); }
+        { return( m_ptr2elem->get_date().format_string() ); }
         bool                    check_title_applicable( const Glib::ustring& ) const;
         bool                    apply_title( const Glib::ustring& );
 
 		void					show( Entry& );
 
-		Glib::RefPtr< Gdk::Pixbuf >&
-		                        get_icon_32( void ) const;
-
-        DiaryElement*           get_element( void )
-        { return m_ptr2entry; }
-
 		void					prepare_for_hiding( Entry& );
-		void					update_formatting_toolbar( void );
 
+		void					update_formatting_toolbar( void );
 		void					update_highlight_button( void );
         void                    toggle_comments( void );
 
+        TextbufferDiary*        get_buffer( void ) { return m_textview->m_buffer; }
+
 	protected:
 		enum TagOperation { TO_NONE, TO_ADD, TO_REMOVE, TO_CREATE_AND_ADD };
 
-		void					populate_tags( void );
 		void					remove_selected_tags( void );
-		void					dismiss_entry( void );
-		void                    print( void );
+        void                    trash_entry( void );
+        void                    restore_entry( void );
+        void                    dismiss_entry( void );
+        void                    print( void );
 		void					toggle_favoredness( void );
 		void					reset_theme( void );
         void                    hide( void );
         void                    hide_before( void );
         void                    hide_after( void );
-        void                    handle_comments_toggled( void );
 
 		void					handle_login( void );
 		void					handle_textview_changed( void );
@@ -115,14 +117,17 @@ class EntryView : public ElementShower< Entry >
 										uint,
 										guint );
 
-		void					handle_iconview_tags_key_release( GdkEventKey* );
-		void					handle_iconview_tags_button_press( GdkEventButton* );
+        void                    focus_tag_entry( void );
+        void                    handle_tag_entry_focus_out( GdkEventFocus* );
+        void                    edit_tag_in_entry( const Tag* );
 
 		// WIDGETS
-		Gtk::Button             *m_button_print;
-		Gtk::ToggleButton		*m_button_toggle_favorite;
-		Gtk::Button				*m_button_dismiss;
-		Gtk::Button				*m_button_reset_theme;
+        Gtk::MenuItem           *m_menuitem_toggle_favorite;
+        Gtk::SeparatorMenuItem  *m_menuseparator_1, *m_menuseparator_2;
+        Gtk::MenuItem           *m_menuitem_reset_theme;
+        Gtk::MenuItem           *m_menuitem_trash;
+        Gtk::MenuItem           *m_menuitem_restore;
+        Gtk::MenuItem           *m_menuitem_dismiss;
 
 		Gtk::Button				*m_button_bold;
 		Gtk::Button				*m_button_italic;
@@ -134,20 +139,31 @@ class EntryView : public ElementShower< Entry >
 		Gtk::Button				*m_button_add_checkbox;
         Gtk::ToggleButton       *m_button_toggle_comments;
 
-		TextviewDiary			*m_textviewdiary;
+		TextviewDiary			*m_textview;
+		Gtk::Box                *m_box_tag_edit;
 		TagWidget				*m_tag_widget;
 		Gtk::Button				*m_button_tag_operation;
-		Gtk::Menu				*m_menu_tag;
-		Gtk::IconView			*m_iconview_tags;
+        WidgetTagList           *m_widgettaglist;
         Gtk::Box                *m_hbox_editing_toolbar;
 		TagOperation			m_tag_operation_cur;
 
-		Glib::RefPtr< Gtk::ListStore >
-								m_liststore_tags;
-
-		Entry					*m_ptr2entry;
 		Entry                   *m_entry_sync;
 
+        // ACTIONS
+        Glib::RefPtr< Gtk::Action > m_action_bold;
+        Glib::RefPtr< Gtk::Action > m_action_italic;
+        Glib::RefPtr< Gtk::Action > m_action_strikethrough;
+        Glib::RefPtr< Gtk::Action > m_action_highlight;
+        Glib::RefPtr< Gtk::Action > m_action_focus_tag;
+        Glib::RefPtr< Gtk::ToggleAction > m_action_toggle_comments;
+        Glib::RefPtr< Gtk::Action > m_action_indent;
+        Glib::RefPtr< Gtk::Action > m_action_unindent;
+        Glib::RefPtr< Gtk::Action > m_action_add_empty_line_above;
+        Glib::RefPtr< Gtk::Action > m_action_remove_empty_line_above;
+        Glib::RefPtr< Gtk::Action > m_action_move_line_up;
+        Glib::RefPtr< Gtk::Action > m_action_move_line_down;
+        Glib::RefPtr< Gtk::Action > m_action_time_stamp;
+
 		bool					m_flag_entrychanged;
 
 	friend class Lifeograph;
