@@ -29,7 +29,7 @@
 #include "lifeobase.hpp"
 #include "diary.hpp"
 #include "views.hpp"
-#include "gui_tag.hpp"
+#include "panel_extra.hpp"
 
 
 using namespace LIFEO;
@@ -43,9 +43,9 @@ TagView::TagView( void )
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_tag", m_vbox );
-		Lifeobase::builder->get_widget( "box_tag_toolbar", m_box_toolbar );
-		Lifeobase::builder->get_widget( "togglebutton_tag_filter", m_button_filter );
-		Lifeobase::builder->get_widget( "button_tag_dismiss", m_button_dismiss );
+		Lifeobase::builder->get_widget_derived( "menu_tag_elem", m_menu );
+		Lifeobase::builder->get_widget( "menuitem_tag_dismiss", m_menuitem_dismiss );
+		Lifeobase::builder->get_widget( "togglebutton_tag_filter", m_togglebutton_filter );
 		Lifeobase::builder->get_widget( "combobox_tag_category", m_combobox_category );
 		Lifeobase::builder->get_widget_derived( "drawingarea_tag_chart", m_widgetchart );
 
@@ -61,9 +61,9 @@ TagView::TagView( void )
 			sigc::mem_fun( this, &TagView::is_row_separator ) );
 
 	// SIGNALS
-	m_button_filter->signal_toggled().connect(
+	m_togglebutton_filter->signal_toggled().connect(
 			sigc::mem_fun( this, &TagView::handle_filter_toggled ) );
-	m_button_dismiss->signal_clicked().connect(
+	m_menuitem_dismiss->signal_activate().connect(
 			sigc::mem_fun( this, &TagView::dismiss_tag ) );
 
 	m_combobox_category->signal_changed().connect(
@@ -84,9 +84,9 @@ TagView::apply_title( const Glib::ustring &name )
 	if( ! check_title_applicable( name ) )
 		return false;
 
-	Diary::d->get_tags()->rename( m_ptr2tag, name );
-	Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2tag );
-	row[ TagPanel::colrec->name ] = Glib::Markup::escape_text( name );
+	Diary::d->get_tags()->rename( m_ptr2elem, name );
+	Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2elem );
+	row[ PanelExtra::colrec->name ] = m_ptr2elem->get_list_str();
 
 	return true;
 }
@@ -104,11 +104,23 @@ TagView::handle_filter_toggled( void )
     if( Lifeobase::m_internaloperation )
         return;
 
-    Diary::d->set_filter_tag( m_button_filter->get_active() ? m_ptr2tag : NULL );
+    // REMOVE EXISTING FILTER IF ANY
+    const Tag *tag( Diary::d->get_filter_tag() );
+    if( tag != NULL && tag != m_ptr2elem )
+    {
+        Diary::d->set_filter_tag( NULL );
+        Gtk::TreeRow row = * Lifeobase::base->get_element_row( tag );
+        row[ PanelExtra::colrec->icon ] = Lifeobase::icons->tag_16;
+    }
+
+    // SET THE NEW FILTER
+    Diary::d->set_filter_tag( m_togglebutton_filter->get_active() ? m_ptr2elem : NULL );
     update_button_filter_tag();
     Lifeobase::panel_diary->update_button_remove_filters();
-    Lifeobase::panel_tag->update_tag_icon( m_ptr2tag );
     Lifeobase::panel_diary->update_entry_list();
+    // UPDATE ICON
+    Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2elem );
+    row[ PanelExtra::colrec->icon ] = m_ptr2elem->get_icon();
 }
 
 void
@@ -124,16 +136,16 @@ TagView::handle_category_changed( void )
 		if( row[ colrec_category.type ]  == TCT_NEW ) // create new
 		{
 			CategoryTags *category = Diary::d->create_tag_ctg();
-			m_ptr2tag->set_category( category );
+			m_ptr2elem->set_category( category );
 			update_combobox_categories();
-			Lifeobase::panel_tag->populate_main();
+			Lifeobase::panel_extra->populate();
 			category->show();
 			Lifeobase::panel_main->start_title_edit();
 		}
 		else	// assign a category or reset
 		{
-			m_ptr2tag->set_category( row[ colrec_category.ptr ] );
-			Lifeobase::panel_tag->populate_main();
+			m_ptr2elem->set_category( row[ colrec_category.ptr ] );
+			Lifeobase::panel_extra->populate();
 		}
 	}
 }
@@ -185,7 +197,7 @@ void
 TagView::update_button_filter_tag( void )
 {
     Lifeobase::m_internaloperation++;
-    m_button_filter->set_active( Diary::d->get_filter_tag() != NULL );
+    m_togglebutton_filter->set_active( Diary::d->get_filter_tag() == m_ptr2elem );
     Lifeobase::m_internaloperation--;
 }
 
@@ -196,14 +208,14 @@ TagView::show( Tag &tag )
     if( Lifeobase::panel_main->is_cur_elem( &tag ) )
         return;
 
-	m_ptr2tag = &tag;
+	m_ptr2elem = &tag;
 
     Lifeobase::panel_main->show( this );
 
 	Lifeobase::m_internaloperation++;
 
 	// BODY
-	m_button_filter->set_active( Diary::d->get_filter_tag() == &tag );
+	update_button_filter_tag();
 
 	for( Gtk::TreeIter iter = m_liststore_categories->children().begin();
 		 iter != m_liststore_categories->children().end();
@@ -252,10 +264,10 @@ TagView::show( Tag &tag )
 	Lifeobase::m_internaloperation--;
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
-TagView::get_icon_32( void ) const
+Menu2*
+TagView::get_menu( void )
 {
-    return Lifeobase::icons->tag_32;
+    return( Diary::d->is_read_only() ? NULL : m_menu );
 }
 
 void
@@ -266,17 +278,17 @@ TagView::dismiss_tag( void )
 
     Diary::d->show();
 
-	Lifeobase::panel_main->remove_element_from_history( m_ptr2tag );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2elem );
 
 	// clear filter if necessary:
-	if( Diary::d->get_filter_tag() == m_ptr2tag )
+	if( Diary::d->get_filter_tag() == m_ptr2elem )
 	{
 		Diary::d->set_filter_tag( NULL );
         Lifeobase::panel_diary->update_button_remove_filters();
         Lifeobase::panel_diary->update_entry_list();
 	}
-	Diary::d->dismiss_tag( m_ptr2tag );
-	Lifeobase::panel_tag->populate_main();
+	Diary::d->dismiss_tag( m_ptr2elem );
+	Lifeobase::panel_extra->populate();
 }
 
 bool
@@ -295,12 +307,12 @@ CategoryTagsView::CategoryTagsView( void )
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_categorytags", m_vbox );
-		Lifeobase::builder->get_widget( "box_ctg_tags_toolbar", m_box_toolbar );
-		Lifeobase::builder->get_widget( "button_ctg_tags_dismiss", m_button_dismiss );
+		Lifeobase::builder->get_widget_derived( "menu_tagctg_elem", m_menu );
+		Lifeobase::builder->get_widget( "menuitem_tagctg_dismiss", m_menuitem_dismiss );
 	}
 	catch( ... ) {}
 
-	m_button_dismiss->signal_clicked().connect(
+	m_menuitem_dismiss->signal_activate().connect(
 			sigc::mem_fun( this, &CategoryTagsView::dismiss_category ) );
 }
 
@@ -311,15 +323,15 @@ CategoryTagsView::show( CategoryTags &category )
     if( Lifeobase::panel_main->is_cur_elem( &category ) )
 		return;
 
-	m_ptr2category = &category;
+	m_ptr2elem = &category;
 
 	Lifeobase::panel_main->show( this );
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
-CategoryTagsView::get_icon_32( void ) const
+Menu2*
+CategoryTagsView::get_menu( void )
 {
-    return Lifeobase::icons->tag_32;
+    return( Diary::d->is_read_only() ? NULL : m_menu );
 }
 
 bool
@@ -335,8 +347,8 @@ CategoryTagsView::apply_title( const Glib::ustring &name )
     if( ! check_title_applicable( name ) )
         return false;
 
-	Diary::d->m_tag_categories.rename_category( m_ptr2category, name );
-	Lifeobase::panel_tag->populate_main();
+	Diary::d->m_tag_categories.rename_category( m_ptr2elem, name );
+	Lifeobase::panel_extra->populate();
 	Lifeobase::view_tag->update_combobox_categories();
 
 	return true;
@@ -350,10 +362,10 @@ CategoryTagsView::dismiss_category( void )
 
     Diary::d->show();
 
-	Lifeobase::panel_main->remove_element_from_history( m_ptr2category );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2elem );
 	// TODO: offer merging with a category
-	Diary::d->dismiss_tag_ctg( m_ptr2category );
-	Lifeobase::panel_tag->populate_main();
+	Diary::d->dismiss_tag_ctg( m_ptr2elem );
+	Lifeobase::panel_extra->populate();
 	Lifeobase::view_tag->update_combobox_categories();
 }
 
@@ -367,8 +379,8 @@ ChapterView::ChapterView( void )
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_chapter", m_vbox );
-		Lifeobase::builder->get_widget( "box_chapter_toolbar", m_box_toolbar );
-		Lifeobase::builder->get_widget( "button_chapter_dismiss", m_button_dismiss );
+		Lifeobase::builder->get_widget_derived( "menu_chapter_elem", m_menu );
+		Lifeobase::builder->get_widget( "menuitem_chapter_dismiss", m_menuitem_dismiss );
 
 //		Lifeobase::builder->get_widget( "label_chapter_period", m_label_period );
 //		Lifeobase::builder->get_widget( "hbox_chapter_period", m_hbox_period );
@@ -386,7 +398,7 @@ ChapterView::ChapterView( void )
 	}
 	
 	// SIGNALS
-	m_button_dismiss->signal_clicked().connect(
+	m_menuitem_dismiss->signal_activate().connect(
 			sigc::mem_fun( this, &ChapterView::dismiss_chapter ) );
 
 	m_entry_begins->signal_changed().connect(
@@ -408,15 +420,15 @@ ChapterView::dismiss_chapter( void )
 
     Diary::d->show();
 
-	Lifeobase::panel_main->remove_element_from_history( m_ptr2chapter );
-	Diary::d->dismiss_chapter( m_ptr2chapter );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2elem );
+	Diary::d->dismiss_chapter( m_ptr2elem );
 	Lifeobase::panel_diary->update_entry_list();
 }
 
 bool
 ChapterView::check_title_applicable( const Glib::ustring &str ) const
 {
-	return( ! str.empty() && str != m_ptr2chapter->m_name );
+	return( ! str.empty() && str != m_ptr2elem->m_name );
 }
 
 bool
@@ -425,9 +437,9 @@ ChapterView::apply_title( const Glib::ustring &str )
 	// a caution against calls by an entry activation event:
 	if( ! check_title_applicable( str ) )
 		return false;
-	m_ptr2chapter->set_name( str );
-	Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2chapter );
-	row[ ListData::colrec->info ] = m_ptr2chapter->get_list_str();
+	m_ptr2elem->set_name( str );
+	Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2elem );
+	row[ ListData::colrec->info ] = m_ptr2elem->get_list_str();
 	return true;
 }
 
@@ -438,7 +450,7 @@ ChapterView::handle_date_changed( void )
 	{
 		Date date( m_entry_begins->get_text() );
 		m_button_date_apply->set_sensitive( 
-				! Diary::d->get_current_chapter_ctg()->get_chapter( date ) );
+				! Diary::d->get_current_chapter_ctg()->get_chapter( date.m_date ) );
 	}
 	catch( LIFEO::Error &er )
 	{
@@ -453,7 +465,7 @@ ChapterView::handle_date_applied( void )
 	if( ! m_button_date_apply->is_sensitive() )
 		return;
 	if( Diary::d->get_current_chapter_ctg()->set_chapter_date(
-			m_ptr2chapter, Date( m_entry_begins->get_text() ) ) )
+			m_ptr2elem, Date( m_entry_begins->get_text() ) ) )
 	{
 		m_button_date_apply->set_sensitive( false );
 		Lifeobase::panel_diary->update_entry_list();
@@ -464,15 +476,15 @@ ChapterView::handle_date_applied( void )
 void
 ChapterView::update_labels( void )
 {
-	if( ! m_ptr2chapter->m_date_begin.is_ordinal() )
+	if( ! m_ptr2elem->m_date_begin.is_ordinal() )
 	{
         Lifeobase::m_internaloperation++;
 
-		m_entry_begins->set_text( m_ptr2chapter->m_date_begin.format_string() );
+		m_entry_begins->set_text( m_ptr2elem->m_date_begin.format_string() );
 
 		CategoryChapters::iterator iter( Diary::d->get_current_chapter_ctg()->find(
-												m_ptr2chapter->get_date().m_date ) );
-		if( m_ptr2chapter->m_time_span == 0 )
+												m_ptr2elem->get_date().m_date ) );
+		if( m_ptr2elem->m_time_span == 0 )
 			m_label_ends->set_text( _( "Unlimited" ) );
 		else
 		{
@@ -487,7 +499,7 @@ ChapterView::update_labels( void )
 void
 ChapterView::add_new_entry( void )
 {
-	Diary::d->create_entry( m_ptr2chapter->get_free_order().m_date );
+	Diary::d->create_entry( m_ptr2elem->get_free_order().m_date );
 
 	Lifeobase::panel_diary->update_entry_list();
 	Lifeobase::panel_diary->update_calendar();
@@ -500,7 +512,7 @@ ChapterView::show( Chapter &chapter )
     if( Lifeobase::panel_main->is_cur_elem( &chapter ) )
         return;
 
-	m_ptr2chapter = &chapter;
+	m_ptr2elem = &chapter;
 
 	Lifeobase::panel_main->show( this );
 
@@ -518,11 +530,10 @@ ChapterView::show( Chapter &chapter )
     m_frame_actions->set_sensitive( ! Diary::d->is_read_only() );
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
-ChapterView::get_icon_32( void ) const
+Menu2*
+ChapterView::get_menu( void )
 {
-    return m_ptr2chapter->m_date_begin.is_ordinal() ?
-                Lifeobase::icons->chapter_32 : Lifeobase::icons->month_32;
+    return( Diary::d->is_read_only() ? NULL : m_menu );
 }
 
 // THEME ===========================================================================================
@@ -533,7 +544,11 @@ ThemeView::ThemeView( void )
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_theme", m_vbox );
-		Lifeobase::builder->get_widget( "box_theme_toolbar", m_box_toolbar );
+        Lifeobase::builder->get_widget_derived( "menu_theme_elem", m_menu );
+        Lifeobase::builder->get_widget( "menuitem_theme_duplicate", m_menuitem_duplicate );
+        Lifeobase::builder->get_widget( "menuitem_theme_default", m_menuitem_make_default );
+        Lifeobase::builder->get_widget( "menuseparator_theme_1", m_menuseparator );
+        Lifeobase::builder->get_widget( "menuitem_theme_dismiss", m_menuitem_dismiss );
 		Lifeobase::builder->get_widget( "fontbutton_theme", m_fontbutton );
 		Lifeobase::builder->get_widget( "colorbutton_theme_bground", m_colorbutton_bground );
 		Lifeobase::builder->get_widget( "colorbutton_theme_text", m_colorbutton_text );
@@ -542,9 +557,6 @@ ThemeView::ThemeView( void )
 		Lifeobase::builder->get_widget( "colorbutton_theme_highlight", m_colorbutton_highlight );
 		Lifeobase::builder->get_widget( "eventbox_theme_preview", m_eventbox_preview );
 		Lifeobase::builder->get_widget( "label_theme_preview", m_label_preview );
-		Lifeobase::builder->get_widget( "button_theme_duplicate", m_button_duplicate );
-		Lifeobase::builder->get_widget( "button_theme_dismiss", m_button_dismiss );
-		Lifeobase::builder->get_widget( "button_theme_default", m_button_make_default );
 	}
 	catch( ... ) { }
 
@@ -562,12 +574,12 @@ ThemeView::ThemeView( void )
 			sigc::mem_fun( *this, &ThemeView::handle_color_changed ) );
 
 	// TOOLBAR
-	m_button_duplicate->signal_clicked().connect(
-			sigc::mem_fun( this, &ThemeView::duplicate ) );
-	m_button_dismiss->signal_clicked().connect(
-			sigc::mem_fun( this, &ThemeView::dismiss_theme ) );
-	m_button_make_default->signal_clicked().connect(
-			sigc::mem_fun( this, &ThemeView::make_default ) );
+    m_menuitem_duplicate->signal_activate().connect(
+            sigc::mem_fun( this, &ThemeView::duplicate ) );
+    m_menuitem_make_default->signal_activate().connect(
+            sigc::mem_fun( this, &ThemeView::make_default ) );
+    m_menuitem_dismiss->signal_activate().connect(
+            sigc::mem_fun( this, &ThemeView::dismiss_theme ) );
 }
 
 void
@@ -577,7 +589,7 @@ ThemeView::show( Theme &theme )
     if( Lifeobase::panel_main->is_cur_elem( &theme ) )
 		return;
 
-	m_ptr2theme = &theme;
+	m_ptr2elem = &theme;
 
 	Lifeobase::panel_main->show( this );
 
@@ -592,14 +604,28 @@ ThemeView::show( Theme &theme )
 	update_preview();
 	bool flag_sensitive = !( theme.is_system() || Diary::d->is_read_only() );
 	m_vbox->set_sensitive( flag_sensitive );
-	m_button_dismiss->set_sensitive( flag_sensitive );
-	m_button_make_default->set_visible( &theme != Diary::d->get_default_theme() );
+	m_menuitem_make_default->set_visible( &theme != Diary::d->get_default_theme() );
+	m_menuseparator->set_visible( flag_sensitive );
+    m_menuitem_dismiss->set_visible( flag_sensitive );
 }
 
-Glib::RefPtr< Gdk::Pixbuf >&
-ThemeView::get_icon_32( void ) const
+Glib::ustring
+ThemeView::get_info_str( void ) const
 {
-    return Lifeobase::icons->theme_32;
+    Glib::ustring str( m_ptr2elem->is_system() ? _( "System theme" ) : _( "Custom theme" ) );
+    if( m_ptr2elem == Diary::d->get_default_theme() )
+    {
+        str += " (";
+        str += _( "Default" );
+        str += ")";
+    }
+    return str;
+}
+
+Menu2*
+ThemeView::get_menu( void )
+{
+    return( Diary::d->is_read_only() ? NULL : m_menu );
 }
 
 bool
@@ -618,8 +644,9 @@ ThemeView::apply_title( const Glib::ustring &name )
     if( ! check_title_applicable( name ) )
         return false;
 
-    Diary::d->m_themes.rename_theme( m_ptr2theme, name );
-    Lifeobase::base->update_theme_list();
+    Diary::d->m_themes.rename_theme( m_ptr2elem, name );
+    Gtk::TreeRow row = * Lifeobase::base->get_element_row( m_ptr2elem );
+    row[ PanelExtra::colrec->name ] = m_ptr2elem->get_list_str();
 
     return true;
 }
@@ -627,18 +654,18 @@ ThemeView::apply_title( const Glib::ustring &name )
 void
 ThemeView::handle_font_changed( void )
 {
-	m_ptr2theme->font = Pango::FontDescription( m_fontbutton->get_font_name() );
+	m_ptr2elem->font = Pango::FontDescription( m_fontbutton->get_font_name() );
 	update_preview();
 }
 
 void
 ThemeView::handle_color_changed( void )
 {
-	m_ptr2theme->color_base = m_colorbutton_bground->get_rgba();
-	m_ptr2theme->color_text = m_colorbutton_text->get_rgba();
-	m_ptr2theme->color_heading = m_colorbutton_heading->get_rgba();
-	m_ptr2theme->color_subheading = m_colorbutton_subheading->get_rgba();
-	m_ptr2theme->color_highlight = m_colorbutton_highlight->get_rgba();
+	m_ptr2elem->color_base = m_colorbutton_bground->get_rgba();
+	m_ptr2elem->color_text = m_colorbutton_text->get_rgba();
+	m_ptr2elem->color_heading = m_colorbutton_heading->get_rgba();
+	m_ptr2elem->color_subheading = m_colorbutton_subheading->get_rgba();
+	m_ptr2elem->color_highlight = m_colorbutton_highlight->get_rgba();
 	update_preview();
 }
 
@@ -649,25 +676,25 @@ ThemeView::update_preview( void )
             "<span color='%1' size='xx-large' weight='bold'>Heading</span>\n"
             " <span color='%2'size='larger' weight='bold'>Subheading</span>\n"
             "Body text <span bgcolor='%3'>highlighted text</span>",
-            convert_gdkcolor_to_html( m_ptr2theme->color_heading ),
-            convert_gdkcolor_to_html( m_ptr2theme->color_subheading ),
-            convert_gdkcolor_to_html( m_ptr2theme->color_highlight ) ) );
+            convert_gdkcolor_to_html( m_ptr2elem->color_heading ),
+            convert_gdkcolor_to_html( m_ptr2elem->color_subheading ),
+            convert_gdkcolor_to_html( m_ptr2elem->color_highlight ) ) );
     m_label_preview->set_markup( str_preview );
-    m_label_preview->override_color( m_ptr2theme->color_text, Gtk::STATE_FLAG_NORMAL );
-    m_label_preview->override_color( m_ptr2theme->color_text, Gtk::STATE_FLAG_INSENSITIVE );
-    m_eventbox_preview->override_background_color( m_ptr2theme->color_base,
+    m_label_preview->override_color( m_ptr2elem->color_text, Gtk::STATE_FLAG_NORMAL );
+    m_label_preview->override_color( m_ptr2elem->color_text, Gtk::STATE_FLAG_INSENSITIVE );
+    m_eventbox_preview->override_background_color( m_ptr2elem->color_base,
                                                    Gtk::STATE_FLAG_NORMAL );
-    m_eventbox_preview->override_background_color( m_ptr2theme->color_base,
+    m_eventbox_preview->override_background_color( m_ptr2elem->color_base,
                                                    Gtk::STATE_FLAG_INSENSITIVE );
-    m_label_preview->override_font( m_ptr2theme->font );
+    m_label_preview->override_font( m_ptr2elem->font );
 }
 
 // creating new themes is done by duplicating existing ones
 void
 ThemeView::duplicate( void )
 {
-	Theme *new_theme = Diary::d->duplicate_theme( m_ptr2theme );
-	Lifeobase::base->update_theme_list();
+	Theme *new_theme = Diary::d->duplicate_theme( m_ptr2elem );
+	Lifeobase::panel_extra->populate();
 	new_theme->show();
 	Lifeobase::panel_main->start_title_edit();
 }
@@ -675,9 +702,10 @@ ThemeView::duplicate( void )
 void
 ThemeView::make_default( void )
 {
-	Diary::d->set_default_theme( m_ptr2theme );
-	Lifeobase::base->update_theme_list();
-	m_button_make_default->set_visible( false );
+	Diary::d->set_default_theme( m_ptr2elem );
+	Lifeobase::panel_extra->populate();
+    Lifeobase::panel_main->refresh_extra_info();
+	m_menuitem_make_default->set_visible( false );
 }
 
 void
@@ -688,12 +716,12 @@ ThemeView::dismiss_theme( void )
 
     Diary::d->show();
 
-	Lifeobase::panel_main->remove_element_from_history( m_ptr2theme );
+	Lifeobase::panel_main->remove_element_from_history( m_ptr2elem );
 
-	Theme *theme = m_ptr2theme; // always be on the safe side
+	Theme *theme = m_ptr2elem; // always be on the safe side
 	ThemeSystem::get()->show();
 	Diary::d->dismiss_theme( theme );
-	Lifeobase::base->update_theme_list();
+	Lifeobase::panel_extra->populate();
 }
 
 // DIARY ===========================================================================================
@@ -701,21 +729,28 @@ DiaryView::DiaryView( void )
 :	m_dialog_password( NULL ), m_dialog_import( NULL ), m_dialog_export( NULL )
 {
 	Diary::shower = this;
-	m_ptr2diary = Diary::d;	// for now no other diary is shown in the view
+	m_ptr2elem = Diary::d;	// for now no other diary is shown in the view
 
-	Gtk::Button *button_import( NULL );
-	Gtk::Button *button_export( NULL );
-    Gtk::Box    *hbox_chapter_ctg( NULL );
+	Gtk::MenuItem   *menuitem_export( NULL );
+    Gtk::Box        *hbox_chapter_ctg( NULL );
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_diary", m_vbox );
 
+        Lifeobase::builder->get_widget_derived( "menu_diary_elem", m_menu );
+        Lifeobase::builder->get_widget( "menuitem_import", m_menuitem_import );
+        Lifeobase::builder->get_widget( "menuitem_export", menuitem_export );
+        Lifeobase::builder->get_widget( "menuseparator_diary_1", m_menuseparator );
+        Lifeobase::builder->get_widget( "menuitem_diary_dont_save",
+                m_menuitem_dont_save );
+
 		Lifeobase::builder->get_widget( "frame_diary_startup", m_frame_startup );
         Lifeobase::builder->get_widget( "frame_diary_chapters", m_frame_chapters );
 
 		Lifeobase::builder->get_widget( "label_path", m_label_path );
 		Lifeobase::builder->get_widget( "label_encryption", m_label_encryption );
 		Lifeobase::builder->get_widget( "button_password", m_button_password );
+        Lifeobase::builder->get_widget( "combobox_diary_spellcheck", m_combobox_spellcheck );
 
 		Lifeobase::builder->get_widget( "cmb_startup_type", m_combobox_startup_type );
 		Lifeobase::builder->get_widget( "label_startup_elem", m_label_startup_elem );
@@ -734,12 +769,6 @@ DiaryView::DiaryView( void )
 
         Lifeobase::builder->get_widget_derived( "drawingarea_diary_chart", m_widgetchart );
 
-		Lifeobase::builder->get_widget( "box_diary_toolbar", m_box_toolbar );
-		Lifeobase::builder->get_widget( "button_import", button_import );
-		Lifeobase::builder->get_widget( "button_export", button_export );
-		Lifeobase::builder->get_widget( "button_log_out_wosaving",
-				m_button_logoutwosaving );
-
 		m_liststore_startup_type = Gtk::ListStore::create( colrec_startup_type );
 		m_liststore_chapter_ctg = Gtk::ListStore::create( colrec_chapter_ctg );
 	}
@@ -770,6 +799,9 @@ DiaryView::DiaryView( void )
 	m_button_password->signal_clicked().connect(
 			sigc::mem_fun( *this, &DiaryView::start_dialog_password ) );
 
+    m_combobox_spellcheck->signal_changed().connect(
+            sigc::mem_fun( this, &DiaryView::handle_language_changed ) );
+
 	m_combobox_startup_type->signal_changed().connect(
 			sigc::mem_fun( this, &DiaryView::handle_startup_type_changed ) );
 	m_label_startup_elem_drop->signal_drag_data_received().connect(
@@ -786,12 +818,11 @@ DiaryView::DiaryView( void )
 	m_button_chapter_ctg_dismiss->signal_clicked().connect(
 			sigc::mem_fun( this, &DiaryView::dismiss_cur_chapter_ctg ) );
 
-	button_import->signal_clicked().connect(
+	m_menuitem_import->signal_activate().connect(
 			sigc::mem_fun( *this, &DiaryView::start_dialog_import ) );
-	button_export->signal_clicked().connect(
+	menuitem_export->signal_activate().connect(
 			sigc::mem_fun( *this, &DiaryView::start_dialog_export ) );
-
-	m_button_logoutwosaving->signal_clicked().connect(
+	m_menuitem_dont_save->signal_activate().connect(
 			sigc::bind( sigc::mem_fun( *Lifeobase::base, &Lifeobase::logout ), false ) );
 }
 
@@ -805,6 +836,26 @@ DiaryView::handle_login( void )
 {
 	Lifeobase::m_internaloperation++;
 
+    // SPELL CHECKING
+	m_combobox_spellcheck->remove_all();
+    m_combobox_spellcheck->append( _( STRING::OFF ) );
+    for( LanguageList::iterator iter = Lifeobase::s_lang_list.begin();
+         iter != Lifeobase::s_lang_list.end(); ++iter )
+    {
+        m_combobox_spellcheck->append( *iter );
+    }
+
+    if( Diary::d->m_language.empty() )
+        m_combobox_spellcheck->set_active_text( _( STRING::OFF ) );
+    else
+    {
+        if( Lifeobase::s_lang_list.find( Diary::d->m_language ) ==
+            Lifeobase::s_lang_list.end() )
+            m_combobox_spellcheck->append( Diary::d->m_language );
+
+        m_combobox_spellcheck->set_active_text( Diary::d->m_language );
+    }
+
 	update_combobox_chapter_ctg();
 	if( Diary::d->m_startup_elem < HOME_FIXED_ELEM )
 		m_combobox_startup_type->set_active( Diary::d->m_startup_elem - 1 );
@@ -813,9 +864,16 @@ DiaryView::handle_login( void )
 
 	Lifeobase::m_internaloperation--;
 
-	m_button_password->set_sensitive( ! Diary::d->is_read_only() );
-    m_frame_startup->set_sensitive( ! Diary::d->is_read_only() );
-    m_frame_chapters->set_sensitive( ! Diary::d->is_read_only() );
+	bool editable( ! Diary::d->is_read_only() );
+	m_button_password->set_sensitive( editable );
+    m_frame_startup->set_sensitive( editable );
+    m_frame_chapters->set_sensitive( editable );
+    m_menuitem_import->set_visible( editable );
+    m_menuseparator->set_visible( editable );
+    m_menuitem_dont_save->set_visible( editable );
+
+    m_label_path->set_markup( Glib::ustring::compose( "<a href=\"file://%1\">%1</a>",
+            Glib::path_get_dirname( Diary::d->m_path ) ) );
 }
 
 void
@@ -826,7 +884,7 @@ DiaryView::show( Diary &diary )
 		return;
 
 	// not necessary for now as there is only one diary to show in the view:
-	// m_ptr2diary = &diary;
+	// m_ptr2elem = &diary;
 
     Lifeobase::panel_main->show( this );
 
@@ -871,19 +929,6 @@ DiaryView::show( Diary &diary )
     points->add( yearmonth_last, value );
 
     m_widgetchart->set_points( points );
-
-#if GTK_CHECK_VERSION(2,18,0)
-	m_label_path->set_markup( Glib::ustring::compose( "<a href=\"file://%1\">%2</a>",
-			Glib::path_get_dirname( diary.m_path ), diary.m_path ) );
-#else
-	m_label_path->set_label( m_path );
-#endif
-}
-
-Glib::RefPtr< Gdk::Pixbuf >&
-DiaryView::get_icon_32( void ) const
-{
-    return Lifeobase::icons->diary_32;
 }
 
 void
@@ -891,8 +936,8 @@ DiaryView::start_dialog_password( void )
 {
 	try
 	{
-		m_dialog_password = new DialogPassword(	m_ptr2diary->m_passphrase,
-				m_ptr2diary->m_passphrase.size() > 0 ?
+		m_dialog_password = new DialogPassword(	m_ptr2elem->m_passphrase,
+				m_ptr2elem->m_passphrase.size() > 0 ?
 		// TRANSLATORS: this is the title of the password dialog
 						_( "Change Password" ) :
 		// TRANSLATORS: this is the title of the password dialog
@@ -909,7 +954,7 @@ DiaryView::start_dialog_password( void )
 	if( m_dialog_password->is_passphrase_set() )
 	// TODO: if( m_dialog_password->run() )
 	{
-		if( m_ptr2diary->set_passphrase( m_dialog_password->get_passphrase() ) )
+		if( m_ptr2elem->set_passphrase( m_dialog_password->get_passphrase() ) )
 		{
 			m_label_encryption->set_label( _( "Encrypted" ) );
 			m_button_password->set_label( _( "Change Password..." ) );
@@ -932,8 +977,7 @@ DiaryView::start_dialog_import( void )
     if( response == RESPONSE_GO )
     {
         Lifeobase::panel_diary->update_entry_list();
-        Lifeobase::panel_tag->populate_main();
-        Lifeobase::base->update_theme_list();
+        Lifeobase::panel_extra->populate();
     }
 }
 
@@ -955,6 +999,15 @@ DiaryView::start_dialog_export( void )
 //	gtk_show_uri( NULL, uri.c_str(), GDK_CURRENT_TIME, &err);
 //}
 
+void
+DiaryView::handle_language_changed( void )
+{
+    if( Lifeobase::m_internaloperation )
+        return;
+    std::string lang( m_combobox_spellcheck->get_active_text() );
+    Diary::d->set_lang( lang == _( STRING::OFF ) ? "" : lang );
+}
+
 void
 DiaryView::handle_startup_type_changed( void )
 {
@@ -1019,8 +1072,8 @@ DiaryView::update_combobox_chapter_ctg( void )
 	Gtk::TreeRow row;
 
 	for( PoolCategoriesChapters::const_iterator iter =
-				m_ptr2diary->m_chapter_categories.begin();
-		 iter != m_ptr2diary->m_chapter_categories.end();
+				m_ptr2elem->m_chapter_categories.begin();
+		 iter != m_ptr2elem->m_chapter_categories.end();
 		 ++iter )
 	{
 		row = * m_liststore_chapter_ctg->append();
@@ -1032,16 +1085,16 @@ DiaryView::update_combobox_chapter_ctg( void )
 		row[ colrec_chapter_ctg.type ] = CCCT_CATEGORY;
 
 		// setting current item:
-		if( m_ptr2diary->m_ptr2chapter_ctg_cur == category )
+		if( m_ptr2elem->m_ptr2chapter_ctg_cur == category )
 			m_combobox_chapter_ctg->set_active( row );
 	}
 
 	m_button_chapter_ctg_rename->set_visible( false );
 	m_button_chapter_ctg_dismiss->set_visible( true );
-	m_button_chapter_ctg_dismiss->set_sensitive( m_ptr2diary->m_chapter_categories.size() > 1 );
+	m_button_chapter_ctg_dismiss->set_sensitive( m_ptr2elem->m_chapter_categories.size() > 1 );
 
 	// separator 2:
-	if( m_ptr2diary->m_chapter_categories.size() > 0 )
+	if( m_ptr2elem->m_chapter_categories.size() > 0 )
 	{
 		row = * m_liststore_chapter_ctg->append();
 		row[ colrec_chapter_ctg.type ] = CCCT_SEPARATOR;
@@ -1065,7 +1118,7 @@ DiaryView::handle_cur_chapter_ctg_changed( void )
 	if( flag_renamed )
 	{
 		Glib::ustring name = m_combobox_chapter_ctg->get_entry_text();
-		bool flag_name_usable = m_ptr2diary->m_chapter_categories.count( name ) < 1;
+		bool flag_name_usable = m_ptr2elem->m_chapter_categories.count( name ) < 1;
 		m_button_chapter_ctg_rename->set_sensitive( flag_name_usable );
 	}
 	else
@@ -1074,13 +1127,13 @@ DiaryView::handle_cur_chapter_ctg_changed( void )
 		switch( row[ colrec_chapter_ctg.type ] )
 		{
 			case CCCT_NEW: // create new
-				m_ptr2diary->m_ptr2chapter_ctg_cur = m_ptr2diary->create_chapter_ctg();
+				m_ptr2elem->m_ptr2chapter_ctg_cur = m_ptr2elem->create_chapter_ctg();
 				update_combobox_chapter_ctg();
 				flag_existing_ctg = true;
 				break;
 			case CCCT_CATEGORY:
 				flag_existing_ctg = true;
-				m_ptr2diary->m_ptr2chapter_ctg_cur = row[ colrec_chapter_ctg.ptr ];
+				m_ptr2elem->m_ptr2chapter_ctg_cur = row[ colrec_chapter_ctg.ptr ];
 				Lifeobase::panel_diary->update_entry_list();
 				break;
 			default:	// for separators
@@ -1098,9 +1151,9 @@ void
 DiaryView::rename_cur_chapter_ctg( void )
 {
 	Glib::ustring name = m_combobox_chapter_ctg->get_entry_text();
-	if( name == m_ptr2diary->m_ptr2chapter_ctg_cur->get_name() )
+	if( name == m_ptr2elem->m_ptr2chapter_ctg_cur->get_name() )
 		return;
-	m_ptr2diary->rename_chapter_ctg( m_ptr2diary->m_ptr2chapter_ctg_cur, name );
+	m_ptr2elem->rename_chapter_ctg( m_ptr2elem->m_ptr2chapter_ctg_cur, name );
 	update_combobox_chapter_ctg();
 }
 
@@ -1112,7 +1165,7 @@ DiaryView::dismiss_cur_chapter_ctg( void )
 
     Diary::d->show();
 
-	m_ptr2diary->dismiss_chapter_ctg( m_ptr2diary->m_ptr2chapter_ctg_cur );
+	m_ptr2elem->dismiss_chapter_ctg( m_ptr2elem->m_ptr2chapter_ctg_cur );
 	update_combobox_chapter_ctg();
 }
 
