@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-	Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)
+	Copyright (C) 2007-2012 Ahmet Öztürk (aoz_2@yahoo.com)
 
 	This file is part of Lifeograph.
 
@@ -34,62 +34,51 @@
 namespace LIFEO
 {
 
-// DIARY ELEMENT VIEW ==============================================================================
-class GUIElement // BEWARE: subject to removal
-{
-	public:
-		typedef sigc::signal< void, Gtk::Widget* >
-								Signal_void_Widget;
-		typedef sigc::signal< void, DiaryElement* >
-								Signal_DiaryElement;
-		typedef sigc::signal< void, const Date& >
-								Signal_Date;
-};
-
 // TAG VIEW ========================================================================================
 class TagView : public ElementShower< Tag >
 {
 	public:
 								TagView( void );
 
-		void					show( Tag &tag );
-
-        DiaryElement*           get_element( void )
-        { return m_ptr2tag; }
-
-        Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon_32( void ) const;
-
         Glib::ustring           get_title_str( void ) const
-        { return m_ptr2tag->m_name; }
+        { return m_ptr2elem->m_name; }
         Glib::ustring           get_info_str( void ) const
-        { return Glib::ustring::compose( _( "Tag with %1 entries" ), m_ptr2tag->get_size() ); }
-
-        bool                    is_title_editable( void ) const
-        { return true; }
-        Glib::ustring           get_title_edit_str( void ) const
-        { return m_ptr2tag->get_name(); }
-        bool                    check_title_applicable( const Glib::ustring& ) const;
-        bool                    apply_title( const Glib::ustring& );
+        { return Glib::ustring::compose( _( "Tag with %1 entries" ), m_ptr2elem->get_size() ); }
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+        Glib::ustring           get_tip_str( void ) const
+        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
+#endif
+        Menu2*                  get_menu( void );
+        Gtk::Widget*            get_extra_tools( void )
+        { return m_togglebutton_filter; }
 
         void                    handle_login( void );
-		void					handle_filter_toggled( void );
-		void					handle_category_changed( void );
-		bool					is_row_separator( const Glib::RefPtr< Gtk::TreeModel >&,
-												  const Gtk::TreeIter );
+        void                    show( Tag &tag );
 
 		void					update_combobox_categories( void );
         void                    update_button_filter_tag( void );
 
-		void					dismiss_tag( void );
-
-		Gtk::ToggleButton		*m_button_filter;
-		Gtk::Button				*m_button_dismiss;
-		Gtk::ComboBox			*m_combobox_category;
-		WidgetChart				*m_widgetchart;
+		enum TagComboType { TCT_NONE, TCT_CATEGORY, TCT_NEW, TCT_SEPARATOR };
 
 	protected:
-		enum TagComboType { TCT_NONE, TCT_CATEGORY, TCT_NEW, TCT_SEPARATOR };
+        bool                    is_title_editable( void ) const
+        { return true; }
+        Glib::ustring           get_title_edit_str( void ) const
+        { return m_ptr2elem->get_name(); }
+        bool                    check_title_applicable( const Glib::ustring& ) const;
+        bool                    apply_title( const Glib::ustring& );
+
+        void                    handle_filter_toggled( void );
+        void                    handle_category_changed( void );
+        bool                    is_row_separator( const Glib::RefPtr< Gtk::TreeModel >&,
+                                                  const Gtk::TreeIter );
+
+        void                    dismiss_tag( void );
+
+        Gtk::ToggleButton       *m_togglebutton_filter;
+        Gtk::MenuItem           *m_menuitem_dismiss;
+		Gtk::ComboBox			*m_combobox_category;
+		WidgetChart				*m_widgetchart;
 
 		class ColrecCategory : public Gtk::TreeModel::ColumnRecord
 		{
@@ -100,12 +89,9 @@ class TagView : public ElementShower< Tag >
 				Gtk::TreeModelColumn< TagComboType >		type;
 		};
 
-		Tag						*m_ptr2tag;	//current tag
-
 		Glib::RefPtr< Gtk::ListStore >
 								m_liststore_categories;
 		ColrecCategory			colrec_category;
-
 };
 
 // TAG CATEGORY VIEW ===============================================================================
@@ -114,33 +100,30 @@ class CategoryTagsView : public ElementShower< CategoryTags >
 	public:
 								CategoryTagsView( void );
 
-		void					show( CategoryTags& );
-
-        DiaryElement*           get_element( void )
-        { return m_ptr2category; }
-
-        Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon_32( void ) const;
-
         Glib::ustring           get_title_str( void ) const
-        { return m_ptr2category->m_name; }
+        { return m_ptr2elem->m_name; }
         Glib::ustring           get_info_str( void ) const
         { return Glib::ustring::compose( _( "Tag category with %1 tags" ),
-                                         m_ptr2category->size() ); }
+                                         m_ptr2elem->size() ); }
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+        Glib::ustring           get_tip_str( void ) const
+        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
+#endif
+        Menu2*                  get_menu( void );
 
+        void                    show( CategoryTags& );
+
+	protected:
         bool                    is_title_editable( void ) const
         { return true; }
         Glib::ustring           get_title_edit_str( void ) const
-        { return m_ptr2category->get_name(); }
+        { return m_ptr2elem->get_name(); }
         bool                    check_title_applicable( const Glib::ustring& ) const;
         bool                    apply_title( const Glib::ustring& );
 
-	protected:
 		void					dismiss_category( void );
 
-		Gtk::Button				*m_button_dismiss;
-
-		CategoryTags			*m_ptr2category;
+        Gtk::MenuItem           *m_menuitem_dismiss;
 };
 
 // CHAPTER VIEW ====================================================================================
@@ -149,64 +132,59 @@ class ChapterView : public ElementShower< Chapter >
 	public:
 								ChapterView( void );
 
-		void					show( Chapter& );
-
-        DiaryElement*           get_element( void )
-        { return m_ptr2chapter; }
-
-	protected:
-		void					update_labels( void );
-		void					dismiss_chapter( void );
-
-        Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon_32( void ) const;
-
         Glib::ustring           get_title_str( void ) const
         {
-            if( m_ptr2chapter->m_date_begin.is_ordinal() )
+            if( m_ptr2elem->m_date_begin.is_ordinal() )
                 return Glib::ustring::compose( "%1: %2",
-                                               m_ptr2chapter->m_date_begin.format_string(),
-                                               m_ptr2chapter->m_name );
+                                               m_ptr2elem->m_date_begin.format_string(),
+                                               m_ptr2elem->m_name );
             else
-                return m_ptr2chapter->m_name;
+                return m_ptr2elem->m_name;
         }
         Glib::ustring           get_info_str( void ) const
         {
-            if( m_ptr2chapter->m_date_begin.is_ordinal() )
+            if( m_ptr2elem->m_date_begin.is_ordinal() )
                 return Glib::ustring::compose( _( "Topic with %1 entries" ),
-                                               m_ptr2chapter->m_size );
+                                               m_ptr2elem->m_size );
             else
                 return Glib::ustring::compose(
-                        m_ptr2chapter->m_time_span ?
+                        m_ptr2elem->m_time_span ?
                                 _( "Chapter with %1 entries in %2 days" ) :
                                 _( "Chapter with %1 entries" ),
-                        m_ptr2chapter->get_size(), m_ptr2chapter->m_time_span );
+                        m_ptr2elem->get_size(), m_ptr2elem->m_time_span );
         }
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+        Glib::ustring           get_tip_str( void ) const
+        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
+#endif
+        Menu2*                  get_menu( void );
 
+        void                    show( Chapter& );
+
+    protected:
         bool                    is_title_editable( void ) const
         { return true; }
         Glib::ustring           get_title_edit_str( void ) const
-        { return m_ptr2chapter->m_name; }
+        { return m_ptr2elem->m_name; }
 		bool					check_title_applicable( const Glib::ustring& ) const;
 		bool					apply_title( const Glib::ustring& );
 
 		void					handle_date_changed( void );
 		void					handle_date_applied( void );
 
+        void                    update_labels( void );
+
 		void					add_new_entry( void );
+        void                    dismiss_chapter( void );
 
-		Gtk::Button				*m_button_dismiss;
+        Gtk::MenuItem           *m_menuitem_dismiss;
 
-//		Gtk::Label				*m_label_period;
-//		Gtk::HBox				*m_hbox_period;
 		Gtk::Entry				*m_entry_begins;
 		Gtk::Button				*m_button_date_apply;
 		Gtk::Label				*m_label_ends;
 
 		Gtk::Frame				*m_frame_edit;
         Gtk::Frame              *m_frame_actions;
-
-		Chapter					*m_ptr2chapter;
 };
 
 // THEME VIEW ======================================================================================
@@ -215,41 +193,24 @@ class ThemeView : public ElementShower< Theme >
 	public:
 								ThemeView( void );
 
-		void					show( Theme& );
-
-        DiaryElement*           get_element( void )
-        { return m_ptr2theme; }
-
-        Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon_32( void ) const;
-
         Glib::ustring           get_title_str( void ) const
-        { return m_ptr2theme->get_name(); }
-        virtual Glib::ustring   get_info_str( void ) const
-        { return( m_ptr2theme->is_system() ? _( "System theme" ) : _( "Custom theme" ) ); }
+        { return m_ptr2elem->get_name(); }
+        Glib::ustring   get_info_str( void ) const;
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+        Glib::ustring           get_tip_str( void ) const
+        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
+#endif
+        Menu2*                  get_menu( void );
 
-        bool                    is_title_editable( void ) const
-        { return true; }
-        Glib::ustring           get_title_edit_str( void ) const
-        { return m_ptr2theme->get_name(); }
-        bool                    check_title_applicable( const Glib::ustring& ) const;
-        bool                    apply_title( const Glib::ustring& );
+        void                    show( Theme& );
 
 	protected:
-		Gtk::FontButton			*m_fontbutton;
-		Gtk::ColorButton		*m_colorbutton_bground;
-		Gtk::ColorButton		*m_colorbutton_text;
-		Gtk::ColorButton		*m_colorbutton_heading;
-		Gtk::ColorButton		*m_colorbutton_subheading;
-		Gtk::ColorButton		*m_colorbutton_highlight;
-		Gtk::EventBox           *m_eventbox_preview;
-		Gtk::Label              *m_label_preview;
-
-		Gtk::Button				*m_button_duplicate;
-		Gtk::Button				*m_button_dismiss;
-		Gtk::Button				*m_button_make_default;
-
-		Theme					*m_ptr2theme;
+        bool                    is_title_editable( void ) const
+        { return( ! m_ptr2elem->is_system() ); }
+        Glib::ustring           get_title_edit_str( void ) const
+        { return m_ptr2elem->get_name(); }
+        bool                    check_title_applicable( const Glib::ustring& ) const;
+        bool                    apply_title( const Glib::ustring& );
 
 		void					handle_font_changed( void );
 		void					handle_color_changed( void );
@@ -258,6 +219,20 @@ class ThemeView : public ElementShower< Theme >
 		void					duplicate( void );
 		void					make_default( void );
 		void					dismiss_theme( void );
+
+        Gtk::MenuItem           *m_menuitem_duplicate;
+        Gtk::MenuItem           *m_menuitem_make_default;
+        Gtk::SeparatorMenuItem  *m_menuseparator;
+        Gtk::MenuItem           *m_menuitem_dismiss;
+
+        Gtk::FontButton         *m_fontbutton;
+        Gtk::ColorButton        *m_colorbutton_bground;
+        Gtk::ColorButton        *m_colorbutton_text;
+        Gtk::ColorButton        *m_colorbutton_heading;
+        Gtk::ColorButton        *m_colorbutton_subheading;
+        Gtk::ColorButton        *m_colorbutton_highlight;
+        Gtk::EventBox           *m_eventbox_preview;
+        Gtk::Label              *m_label_preview;
 };
 
 // DIARY VIEW ======================================================================================
@@ -267,48 +242,42 @@ class DiaryView : public ElementShower< Diary >
 								DiaryView( void );
 								~DiaryView( void );
 
-		void					handle_login( void );
-
-		void					show( Diary& );
-
-		DiaryElement*           get_element( void )
-		{ return m_ptr2diary; }
-
-        Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon_32( void ) const;
-
         Glib::ustring           get_list_str( void ) const
         { return Glib::ustring::compose( "<b>%1</b>",
                 Glib::Markup::escape_text(
-                        Glib::filename_display_basename( m_ptr2diary->m_path ) ) ); }
+                        Glib::filename_display_basename( m_ptr2elem->m_path ) ) ); }
         Glib::ustring           get_title_str( void ) const
-        { return m_ptr2diary->m_name; }
+        { return m_ptr2elem->m_name; }
         Glib::ustring           get_info_str( void ) const
         {
             int timespan( 0 );
             // FIXME: does not work for some obscure reason..
-            for( Entryciter iter_entry = m_ptr2diary->m_entries.begin();
-                    iter_entry != m_ptr2diary->m_entries.end();
+            for( Entryciter iter_entry = m_ptr2elem->m_entries.begin();
+                    iter_entry != m_ptr2elem->m_entries.end();
                     ++iter_entry )
             {
                 if( ! iter_entry->second->get_date().is_ordinal() )
                 {
-                    timespan = m_ptr2diary->m_entries.rbegin()->second->get_date().
+                    timespan = m_ptr2elem->m_entries.rbegin()->second->get_date().
                             calculate_days_between( iter_entry->second->get_date() );
                     break;
                 }
             }
             return Glib::ustring::compose( _( "Diary with %1 entries spanning %2 days" ),
-                                           m_ptr2diary->m_entries.size(),
+                                           m_ptr2elem->m_entries.size(),
                                            timespan );
         }
-		// DIALOGS
+
+        void                    handle_login( void );
+        void                    show( Diary& );
+
+	protected:
+        // DIALOGS
 		void					start_dialog_password( void );
 		void					start_dialog_import( void );
 		void					start_dialog_export( void );
 		void					open_diary_folder( void );
-
-	protected:
+        void                    handle_language_changed( void );
 		void					handle_startup_type_changed( void );
 		void					handle_startup_elem_dropped(
 										const Glib::RefPtr< Gdk::DragContext >&,
@@ -324,13 +293,16 @@ class DiaryView : public ElementShower< Diary >
 		bool					is_row_separator( const Glib::RefPtr< Gtk::TreeModel >&,
 												  const Gtk::TreeIter );
 
+        Gtk::MenuItem           *m_menuitem_import;
+        Gtk::SeparatorMenuItem  *m_menuseparator;
+        Gtk::MenuItem           *m_menuitem_dont_save;
+
         Gtk::Frame              *m_frame_startup;
         Gtk::Frame              *m_frame_chapters;
 
 		Gtk::Label				*m_label_path;
 		Gtk::Label				*m_label_encryption;
-		Gtk::Button				*m_button_logoutwosaving;
-		Gtk::CheckButton		*m_checkbutton_autologout;
+        Gtk::ComboBoxText       *m_combobox_spellcheck;
 		Gtk::Button				*m_button_password;
         WidgetChart             *m_widgetchart;
 
@@ -376,10 +348,6 @@ class DiaryView : public ElementShower< Diary >
 		DialogPassword			*m_dialog_password;
 		DialogImport			*m_dialog_import;
 		DialogExport			*m_dialog_export;
-
-		Diary					*m_ptr2diary;
-
-	friend class Lifeograph;
 };
 
 } // end of namespace LIFEO
