@@ -905,7 +905,8 @@ TextbufferDiary::process_new_line( void )
                     if( char_lf != '1' )
                         return false;
                     char_lf = ' ';
-                    text += Glib::ustring::compose( "%1%2 ", ++value, iter_start.get_char() );
+                    text += Glib::ustring::compose<int,char>(
+                            "%1%2 ", ++value, iter_start.get_char() );
                     break;
                 case '\t':
                     if( char_lf != '*' )
