@@ -23,13 +23,12 @@
 #ifndef LIFEOGRAPH_TEXTVIEW_HEADER
 #define LIFEOGRAPH_TEXTVIEW_HEADER
 
+
 #include <deque>
-#include <gtkmm/textview.h>
-#include <gdkmm/cursor.h>
 
 extern "C"
 {
-#include <gtkspell/gtkspell.h>
+#include <enchant/enchant.h>
 }
 
 #include "helpers.hpp"
@@ -57,6 +56,7 @@ enum LinkStatus
 	LS_FILE_UNKNOWN
 };
 
+// UNDO ============================================================================================
 class UndoEdit : public Undoable
 {
 	public:
@@ -177,6 +177,7 @@ class UndoErase : public UndoEdit
 
 };
 
+// LINKS ===========================================================================================
 class Link
 {
 	public:
@@ -252,12 +253,31 @@ class LinkCheck : public Link
 		unsigned int				m_state_index;
 };
 
+class InlineImage
+{
+    public:
+        InlineImage( const Glib::RefPtr< Gtk::TextMark >& );
+        ~InlineImage();
 
+        Glib::RefPtr< Gtk::TextMark > m_mark;
+};
+
+// NEW LINE PREDICATE ==============================================================================
+class PredicateNL
+{
+  public:
+    bool operator()( gunichar ch ) const
+    {
+        return( ch == '\n' );
+    }
+};
+
+// TEXTBUFFER ======================================================================================
 class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 {
 	public:
 		typedef void ( TextbufferDiary::*ParsingApplierFn )( void );
-	
+
 //		typedef sigc::signal< LinkStatus, Date >
 //									Signal_LinkStatus_Date;
 		typedef sigc::signal< void, const Glib::ustring& >
@@ -285,8 +305,13 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 		void						toggle_highlight( void );
 		void						toggle_strikethrough( void );
 
-        void                        show_comments( bool );
+        void                        set_comment_visibility( bool );
+        bool                        get_comment_visibility( void ) const
+        { return m_tag_comment->property_invisible(); }
 
+        static void                 calculate_para_bounds( Gtk::TextIter&, Gtk::TextIter& );
+        bool                        calculate_multiline_selection_bounds( Gtk::TextIter&,
+                                                                          Gtk::TextIter& );
 		void						handle_indent( void );
 		void						handle_unindent( void );
 
@@ -294,10 +319,13 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 		void						add_checkbox( void );
 		void						add_empty_line_above( void );
 		void						remove_empty_line_above( void );
+        void                        move_line_up( void );
+        void                        move_line_down( void );
 		void						insert_link( DiaryElement* );
 		void						insert_time_stamp( void );
 
-		void						set_spellcheck( bool );
+        std::string                 set_language( std::string );
+
 		void						set_theme( const Theme* );
 
 		void						handle_menu( Gtk::Menu* );
@@ -309,9 +337,9 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 		void						on_erase( const Gtk::TextIter&,
 											  const Gtk::TextIter& );
 
-		void						on_apply_tag( const Glib::RefPtr< TextBuffer::Tag >&,
+		/*void						on_apply_tag( const Glib::RefPtr< TextBuffer::Tag >&,
 												  const Gtk::TextIter&,
-												  const Gtk::TextIter& );
+												  const Gtk::TextIter& );*/
 
 		void						on_mark_set( const TextBuffer::iterator&,
 												 const Glib::RefPtr< TextBuffer::Mark >& );
@@ -320,7 +348,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 		bool						process_new_line( void );
 
 		// PARSING
-		void                        parse( unsigned int, unsigned int );
+        void                        parse( const Gtk::TextIter&, const Gtk::TextIter& );
         void                        reparse( void );
 
 		void						apply_hidden_link_tags( Gtk::TextIter&,
@@ -345,15 +373,31 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 
 		gunichar                    get_char_at( int );
 
+        void                        handle_word( void );
+
+        void                        handle_spellcheck_toggled( void );
+        void                        handle_language_changed( const std::string&,
+                                                             const Gtk::RadioMenuItem* );
+        Gtk::Menu*                  build_languages_menu( void );
+        void                        add_suggestion_menus( const Glib::ustring&, Gtk::Menu* );
+        void                        ignore_misspelled_word( const Glib::ustring& );
+        void                        replace_misspelled_word( const Glib::ustring& );
+        void                        add_word_to_dictionary( const Glib::ustring& );
+
 		Glib::ustring::size_type	parser_open_tag_begin;
 		Glib::ustring::size_type	parser_open_tag_end;
 		bool						parser_open_tag_is_link;
 		Glib::ustring::size_type	parser_offset_insert_prev;
 
+        static PredicateNL          s_predicate_nl;
+
 		// LINKS
 		void						clear_links( int, int );
 		void						clear_links( void );
 
+		void                        clear_images( int, int& );
+        void                        clear_images( void );
+
         // TAGS
         // TODO: move these program-wide objects out of this class as...
         // ...there may be other instances of TextbufferDiary in the future
@@ -373,6 +417,8 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         Glib::RefPtr< Tag >         m_tag_link_broken;
         Glib::RefPtr< Tag >         m_tag_link_hidden;
         static Glib::RefPtr< Tag >  m_tag_checkbox;
+        Glib::RefPtr< Tag >         m_tag_image;
+        Glib::RefPtr< Tag >         m_tag_misspelled;
 
         typedef std::vector< Glib::RefPtr< Tag > > VecTags;
         VecTags                     m_tags;
@@ -385,14 +431,20 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 
 		// OTHER VARIABLES
 		bool						m_flag_settextoperation;
-		bool						m_flag_ongoingoperation;
+        int                         m_flag_ongoing_operation;   // Incremental to allow nesting
 		bool						m_flag_parsing;
 		Entry						*m_ptr2entry;
 		Gtk::TextView				*m_ptr2textview;
-		GtkSpell					*m_ptr2spellobj;
 
 		typedef std::list< Link* >	ListLinks;
 		ListLinks					m_list_links;
+		typedef std::set< InlineImage* >
+		                            ListImages;
+		ListImages                  m_list_images;
+
+		// ENCHANT SPELLCHECKER
+        EnchantDict                 *m_enchant_dict;
+        int                         m_spell_suggest_offset;
 
 	friend class DialogTheme;
 	friend class EntryView;
@@ -400,7 +452,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 	friend class TextviewDiary;
 };
 
-
+// TEXTVIEW ========================================================================================
 class TextviewDiary : public Gtk::TextView
 {
 	public:
@@ -409,7 +461,7 @@ class TextviewDiary : public Gtk::TextView
 
         void                        set_richtext( Entry* );
 
-		static TextbufferDiary		*m_buffer;
+        TextbufferDiary             *m_buffer;
 
 	protected:
 		void						update_link( void );
